/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output, and Bison version.  */
#define YYBISON 30802

/* Bison version string.  */
#define YYBISON_VERSION "3.8.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1


/* Substitute the variable and function names.  */
#define yyparse         swf4parse
#define yylex           swf4lex
#define yyerror         swf4error
#define yydebug         swf4debug
#define yynerrs         swf4nerrs
#define yylval          swf4lval
#define yychar          swf4char

/* First part of user prologue.  */
#line 5 "./swf4compiler.y"


#include <time.h>
#include <string.h>
#include <stdlib.h>
#include "compile.h"
#include "actiontypes.h"
#include "assembler.h"

#define YYERROR_VERBOSE 1


#line 91 "swf4compiler.tab.c"

# ifndef YY_CAST
#  ifdef __cplusplus
#   define YY_CAST(Type, Val) static_cast<Type> (Val)
#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
#  else
#   define YY_CAST(Type, Val) ((Type) (Val))
#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
#  endif
# endif
# ifndef YY_NULLPTR
#  if defined __cplusplus
#   if 201103L <= __cplusplus
#    define YY_NULLPTR nullptr
#   else
#    define YY_NULLPTR 0
#   endif
#  else
#   define YY_NULLPTR ((void*)0)
#  endif
# endif

#include "swf4compiler.tab.h"
/* Symbol kind.  */
enum yysymbol_kind_t
{
  YYSYMBOL_YYEMPTY = -2,
  YYSYMBOL_YYEOF = 0,                      /* "end of file"  */
  YYSYMBOL_YYerror = 1,                    /* error  */
  YYSYMBOL_YYUNDEF = 2,                    /* "invalid token"  */
  YYSYMBOL_BREAK = 3,                      /* BREAK  */
  YYSYMBOL_FOR = 4,                        /* FOR  */
  YYSYMBOL_CONTINUE = 5,                   /* CONTINUE  */
  YYSYMBOL_IF = 6,                         /* IF  */
  YYSYMBOL_ELSE = 7,                       /* ELSE  */
  YYSYMBOL_DO = 8,                         /* DO  */
  YYSYMBOL_WHILE = 9,                      /* WHILE  */
  YYSYMBOL_THIS = 10,                      /* THIS  */
  YYSYMBOL_EVAL = 11,                      /* EVAL  */
  YYSYMBOL_TIME = 12,                      /* TIME  */
  YYSYMBOL_RANDOM = 13,                    /* RANDOM  */
  YYSYMBOL_LENGTH = 14,                    /* LENGTH  */
  YYSYMBOL_INT = 15,                       /* INT  */
  YYSYMBOL_CONCAT = 16,                    /* CONCAT  */
  YYSYMBOL_DUPLICATECLIP = 17,             /* DUPLICATECLIP  */
  YYSYMBOL_REMOVECLIP = 18,                /* REMOVECLIP  */
  YYSYMBOL_TRACE = 19,                     /* TRACE  */
  YYSYMBOL_STARTDRAG = 20,                 /* STARTDRAG  */
  YYSYMBOL_STOPDRAG = 21,                  /* STOPDRAG  */
  YYSYMBOL_ORD = 22,                       /* ORD  */
  YYSYMBOL_CHR = 23,                       /* CHR  */
  YYSYMBOL_CALLFRAME = 24,                 /* CALLFRAME  */
  YYSYMBOL_GETURL = 25,                    /* GETURL  */
  YYSYMBOL_GETURL1 = 26,                   /* GETURL1  */
  YYSYMBOL_LOADMOVIE = 27,                 /* LOADMOVIE  */
  YYSYMBOL_LOADMOVIENUM = 28,              /* LOADMOVIENUM  */
  YYSYMBOL_LOADVARIABLES = 29,             /* LOADVARIABLES  */
  YYSYMBOL_POSTURL = 30,                   /* POSTURL  */
  YYSYMBOL_SUBSTR = 31,                    /* SUBSTR  */
  YYSYMBOL_GETPROPERTY = 32,               /* GETPROPERTY  */
  YYSYMBOL_NEXTFRAME = 33,                 /* NEXTFRAME  */
  YYSYMBOL_PREVFRAME = 34,                 /* PREVFRAME  */
  YYSYMBOL_PLAY = 35,                      /* PLAY  */
  YYSYMBOL_STOP = 36,                      /* STOP  */
  YYSYMBOL_TOGGLEQUALITY = 37,             /* TOGGLEQUALITY  */
  YYSYMBOL_STOPSOUNDS = 38,                /* STOPSOUNDS  */
  YYSYMBOL_GOTOFRAME = 39,                 /* GOTOFRAME  */
  YYSYMBOL_GOTOANDPLAY = 40,               /* GOTOANDPLAY  */
  YYSYMBOL_FRAMELOADED = 41,               /* FRAMELOADED  */
  YYSYMBOL_SETTARGET = 42,                 /* SETTARGET  */
  YYSYMBOL_ASM = 43,                       /* ASM  */
  YYSYMBOL_ASMADD = 44,                    /* ASMADD  */
  YYSYMBOL_ASMDIVIDE = 45,                 /* ASMDIVIDE  */
  YYSYMBOL_ASMMULTIPLY = 46,               /* ASMMULTIPLY  */
  YYSYMBOL_ASMEQUALS = 47,                 /* ASMEQUALS  */
  YYSYMBOL_ASMLESS = 48,                   /* ASMLESS  */
  YYSYMBOL_ASMLOGICALAND = 49,             /* ASMLOGICALAND  */
  YYSYMBOL_ASMLOGICALOR = 50,              /* ASMLOGICALOR  */
  YYSYMBOL_ASMLOGICALNOT = 51,             /* ASMLOGICALNOT  */
  YYSYMBOL_ASMSTRINGAND = 52,              /* ASMSTRINGAND  */
  YYSYMBOL_ASMSTRINGEQUALS = 53,           /* ASMSTRINGEQUALS  */
  YYSYMBOL_ASMSTRINGEXTRACT = 54,          /* ASMSTRINGEXTRACT  */
  YYSYMBOL_ASMSTRINGLENGTH = 55,           /* ASMSTRINGLENGTH  */
  YYSYMBOL_ASMMBSTRINGEXTRACT = 56,        /* ASMMBSTRINGEXTRACT  */
  YYSYMBOL_ASMMBSTRINGLENGTH = 57,         /* ASMMBSTRINGLENGTH  */
  YYSYMBOL_ASMPOP = 58,                    /* ASMPOP  */
  YYSYMBOL_ASMPUSH = 59,                   /* ASMPUSH  */
  YYSYMBOL_ASMASCIITOCHAR = 60,            /* ASMASCIITOCHAR  */
  YYSYMBOL_ASMCHARTOASCII = 61,            /* ASMCHARTOASCII  */
  YYSYMBOL_ASMTOINTEGER = 62,              /* ASMTOINTEGER  */
  YYSYMBOL_ASMCALL = 63,                   /* ASMCALL  */
  YYSYMBOL_ASMIF = 64,                     /* ASMIF  */
  YYSYMBOL_ASMJUMP = 65,                   /* ASMJUMP  */
  YYSYMBOL_ASMGETVARIABLE = 66,            /* ASMGETVARIABLE  */
  YYSYMBOL_ASMSETVARIABLE = 67,            /* ASMSETVARIABLE  */
  YYSYMBOL_ASMGETURL2 = 68,                /* ASMGETURL2  */
  YYSYMBOL_ASMGETPROPERTY = 69,            /* ASMGETPROPERTY  */
  YYSYMBOL_ASMGOTOFRAME2 = 70,             /* ASMGOTOFRAME2  */
  YYSYMBOL_ASMREMOVESPRITE = 71,           /* ASMREMOVESPRITE  */
  YYSYMBOL_ASMSETPROPERTY = 72,            /* ASMSETPROPERTY  */
  YYSYMBOL_ASMSETTARGET2 = 73,             /* ASMSETTARGET2  */
  YYSYMBOL_ASMSTARTDRAG = 74,              /* ASMSTARTDRAG  */
  YYSYMBOL_ASMWAITFORFRAME2 = 75,          /* ASMWAITFORFRAME2  */
  YYSYMBOL_ASMCLONESPRITE = 76,            /* ASMCLONESPRITE  */
  YYSYMBOL_ASMENDDRAG = 77,                /* ASMENDDRAG  */
  YYSYMBOL_ASMGETTIME = 78,                /* ASMGETTIME  */
  YYSYMBOL_ASMRANDOMNUMBER = 79,           /* ASMRANDOMNUMBER  */
  YYSYMBOL_ASMTRACE = 80,                  /* ASMTRACE  */
  YYSYMBOL_ASMMBASCIITOCHAR = 81,          /* ASMMBASCIITOCHAR  */
  YYSYMBOL_ASMMBCHARTOASCII = 82,          /* ASMMBCHARTOASCII  */
  YYSYMBOL_ASMSUBSTRACT = 83,              /* ASMSUBSTRACT  */
  YYSYMBOL_ASMSTRINGLESS = 84,             /* ASMSTRINGLESS  */
  YYSYMBOL_TELLTARGET = 85,                /* TELLTARGET  */
  YYSYMBOL_BROKENSTRING = 86,              /* BROKENSTRING  */
  YYSYMBOL_STRING = 87,                    /* STRING  */
  YYSYMBOL_NUMBER = 88,                    /* NUMBER  */
  YYSYMBOL_IDENTIFIER = 89,                /* IDENTIFIER  */
  YYSYMBOL_PATH = 90,                      /* PATH  */
  YYSYMBOL_EQ = 91,                        /* "=="  */
  YYSYMBOL_LE = 92,                        /* "<="  */
  YYSYMBOL_GE = 93,                        /* ">="  */
  YYSYMBOL_NE = 94,                        /* "!="  */
  YYSYMBOL_LAN = 95,                       /* "&&"  */
  YYSYMBOL_LOR = 96,                       /* "||"  */
  YYSYMBOL_INC = 97,                       /* "++"  */
  YYSYMBOL_DEC = 98,                       /* "--"  */
  YYSYMBOL_IEQ = 99,                       /* "+="  */
  YYSYMBOL_DEQ = 100,                      /* "/="  */
  YYSYMBOL_MEQ = 101,                      /* "*="  */
  YYSYMBOL_SEQ = 102,                      /* "-="  */
  YYSYMBOL_STREQ = 103,                    /* "==="  */
  YYSYMBOL_STRNE = 104,                    /* "!=="  */
  YYSYMBOL_STRCMP = 105,                   /* "<=>"  */
  YYSYMBOL_PARENT = 106,                   /* ".."  */
  YYSYMBOL_END = 107,                      /* "end"  */
  YYSYMBOL_108_ = 108,                     /* ','  */
  YYSYMBOL_109_ = 109,                     /* '='  */
  YYSYMBOL_110_ = 110,                     /* '?'  */
  YYSYMBOL_111_ = 111,                     /* ':'  */
  YYSYMBOL_112_ = 112,                     /* '<'  */
  YYSYMBOL_113_ = 113,                     /* '>'  */
  YYSYMBOL_114_ = 114,                     /* '&'  */
  YYSYMBOL_115_ = 115,                     /* '+'  */
  YYSYMBOL_116_ = 116,                     /* '-'  */
  YYSYMBOL_117_ = 117,                     /* '*'  */
  YYSYMBOL_118_ = 118,                     /* '/'  */
  YYSYMBOL_UMINUS = 119,                   /* UMINUS  */
  YYSYMBOL_120_ = 120,                     /* '!'  */
  YYSYMBOL_POSTFIX = 121,                  /* POSTFIX  */
  YYSYMBOL_NEGATE = 122,                   /* NEGATE  */
  YYSYMBOL_123_ = 123,                     /* '{'  */
  YYSYMBOL_124_ = 124,                     /* '}'  */
  YYSYMBOL_125_ = 125,                     /* ';'  */
  YYSYMBOL_126_ = 126,                     /* '('  */
  YYSYMBOL_127_ = 127,                     /* ')'  */
  YYSYMBOL_128_ = 128,                     /* '.'  */
  YYSYMBOL_YYACCEPT = 129,                 /* $accept  */
  YYSYMBOL_program = 130,                  /* program  */
  YYSYMBOL_elems = 131,                    /* elems  */
  YYSYMBOL_elem = 132,                     /* elem  */
  YYSYMBOL_stmt = 133,                     /* stmt  */
  YYSYMBOL_assign_stmts = 134,             /* assign_stmts  */
  YYSYMBOL_statements = 135,               /* statements  */
  YYSYMBOL_if_stmt = 136,                  /* if_stmt  */
  YYSYMBOL_expr_opt = 137,                 /* expr_opt  */
  YYSYMBOL_iter_stmt = 138,                /* iter_stmt  */
  YYSYMBOL_assign_stmts_opt = 139,         /* assign_stmts_opt  */
  YYSYMBOL_cont_stmt = 140,                /* cont_stmt  */
  YYSYMBOL_break_stmt = 141,               /* break_stmt  */
  YYSYMBOL_urlmethod = 142,                /* urlmethod  */
  YYSYMBOL_level = 143,                    /* level  */
  YYSYMBOL_void_function_call = 144,       /* void_function_call  */
  YYSYMBOL_function_call = 145,            /* function_call  */
  YYSYMBOL_pf_expr = 146,                  /* pf_expr  */
  YYSYMBOL_rhs_expr = 147,                 /* rhs_expr  */
  YYSYMBOL_variable = 148,                 /* variable  */
  YYSYMBOL_sprite = 149,                   /* sprite  */
  YYSYMBOL_lhs_expr = 150,                 /* lhs_expr  */
  YYSYMBOL_assign_stmt = 151,              /* assign_stmt  */
  YYSYMBOL_152_1 = 152,                    /* $@1  */
  YYSYMBOL_expr = 153,                     /* expr  */
  YYSYMBOL_push_item = 154,                /* push_item  */
  YYSYMBOL_push_list = 155,                /* push_list  */
  YYSYMBOL_opcode_list = 156,              /* opcode_list  */
  YYSYMBOL_opcode = 157,                   /* opcode  */
  YYSYMBOL_158_2 = 158                     /* @2  */
};
typedef enum yysymbol_kind_t yysymbol_kind_t;




#ifdef short
# undef short
#endif

/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
   <limits.h> and (if available) <stdint.h> are included
   so that the code can choose integer types of a good width.  */

#ifndef __PTRDIFF_MAX__
# include <limits.h> /* INFRINGES ON USER NAME SPACE */
# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
#  define YY_STDINT_H
# endif
#endif

/* Narrow types that promote to a signed type and that can represent a
   signed or unsigned integer of at least N bits.  In tables they can
   save space and decrease cache pressure.  Promoting to a signed type
   helps avoid bugs in integer arithmetic.  */

#ifdef __INT_LEAST8_MAX__
typedef __INT_LEAST8_TYPE__ yytype_int8;
#elif defined YY_STDINT_H
typedef int_least8_t yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef __INT_LEAST16_MAX__
typedef __INT_LEAST16_TYPE__ yytype_int16;
#elif defined YY_STDINT_H
typedef int_least16_t yytype_int16;
#else
typedef short yytype_int16;
#endif

/* Work around bug in HP-UX 11.23, which defines these macros
   incorrectly for preprocessor constants.  This workaround can likely
   be removed in 2023, as HPE has promised support for HP-UX 11.23
   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
#ifdef __hpux
# undef UINT_LEAST8_MAX
# undef UINT_LEAST16_MAX
# define UINT_LEAST8_MAX 255
# define UINT_LEAST16_MAX 65535
#endif

#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
typedef __UINT_LEAST8_TYPE__ yytype_uint8;
#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST8_MAX <= INT_MAX)
typedef uint_least8_t yytype_uint8;
#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
typedef unsigned char yytype_uint8;
#else
typedef short yytype_uint8;
#endif

#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
typedef __UINT_LEAST16_TYPE__ yytype_uint16;
#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST16_MAX <= INT_MAX)
typedef uint_least16_t yytype_uint16;
#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
typedef unsigned short yytype_uint16;
#else
typedef int yytype_uint16;
#endif

#ifndef YYPTRDIFF_T
# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
#  define YYPTRDIFF_T __PTRDIFF_TYPE__
#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
# elif defined PTRDIFF_MAX
#  ifndef ptrdiff_t
#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  endif
#  define YYPTRDIFF_T ptrdiff_t
#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
# else
#  define YYPTRDIFF_T long
#  define YYPTRDIFF_MAXIMUM LONG_MAX
# endif
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned
# endif
#endif

#define YYSIZE_MAXIMUM                                  \
  YY_CAST (YYPTRDIFF_T,                                 \
           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
            ? YYPTRDIFF_MAXIMUM                         \
            : YY_CAST (YYSIZE_T, -1)))

#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))


/* Stored state numbers (used for stacks). */
typedef yytype_int16 yy_state_t;

/* State numbers in computations.  */
typedef int yy_state_fast_t;

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif


#ifndef YY_ATTRIBUTE_PURE
# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
# else
#  define YY_ATTRIBUTE_PURE
# endif
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
# else
#  define YY_ATTRIBUTE_UNUSED
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YY_USE(E) ((void) (E))
#else
# define YY_USE(E) /* empty */
#endif

/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
# else
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# endif
# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
# define YY_IGNORE_USELESS_CAST_BEGIN                          \
    _Pragma ("GCC diagnostic push")                            \
    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
# define YY_IGNORE_USELESS_CAST_END            \
    _Pragma ("GCC diagnostic pop")
#endif
#ifndef YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_END
#endif


#define YY_ASSERT(E) ((void) (0 && (E)))

#if !defined yyoverflow

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* !defined yyoverflow */

#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yy_state_t yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYPTRDIFF_T yynewbytes;                                         \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYPTRDIFF_T yyi;                      \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  112
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   1684

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  129
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  30
/* YYNRULES -- Number of rules.  */
#define YYNRULES  188
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  433

/* YYMAXUTOK -- Last valid token kind.  */
#define YYMAXUTOK   365


/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, with out-of-bounds checking.  */
#define YYTRANSLATE(YYX)                                \
  (0 <= (YYX) && (YYX) <= YYMAXUTOK                     \
   ? YY_CAST (yysymbol_kind_t, yytranslate[YYX])        \
   : YYSYMBOL_YYUNDEF)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,   120,     2,     2,     2,     2,   114,     2,
     126,   127,   117,   115,   108,   116,   128,   118,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,   111,   125,
     112,   109,   113,   110,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,   123,     2,   124,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,    99,   100,   101,   102,   103,   104,
     105,   106,   107,   119,   121,   122
};

#if YYDEBUG
/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_int16 yyrline[] =
{
       0,   164,   164,   170,   171,   176,   180,   181,   182,   183,
     184,   185,   186,   187,   191,   192,   196,   197,   198,   205,
     221,   237,   249,   263,   277,   287,   298,   308,   309,   333,
     348,   360,   368,   390,   391,   395,   403,   412,   414,   421,
     429,   433,   440,   447,   451,   456,   463,   470,   479,   486,
     493,   501,   508,   520,   529,   533,   537,   541,   545,   549,
     553,   560,   567,   573,   579,   586,   590,   604,   617,   621,
     625,   629,   633,   637,   641,   645,   650,   656,   665,   676,
     690,   692,   695,   700,   706,   711,   717,   722,   730,   745,
     755,   770,   780,   785,   789,   795,   800,   805,   810,   815,
     820,   825,   830,   836,   841,   846,   850,   854,   858,   863,
     867,   871,   883,   885,   892,   895,   898,   901,   904,   907,
     912,   917,   922,   926,   929,   928,   933,   935,   943,   951,
     964,   977,   981,   988,   995,  1002,  1009,  1018,  1031,  1044,
    1057,  1072,  1076,  1080,  1081,  1085,  1086,  1090,  1090,  1096,
    1097,  1098,  1099,  1100,  1101,  1102,  1103,  1104,  1105,  1106,
    1107,  1108,  1109,  1110,  1111,  1112,  1113,  1114,  1115,  1116,
    1117,  1118,  1119,  1120,  1121,  1122,  1123,  1124,  1125,  1126,
    1127,  1128,  1129,  1130,  1132,  1136,  1140,  1143,  1147
};
#endif

/** Accessing symbol of state STATE.  */
#define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])

#if YYDEBUG || 0
/* The user-facing name of the symbol whose (internal) number is
   YYSYMBOL.  No bounds checking.  */
static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;

/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "\"end of file\"", "error", "\"invalid token\"", "BREAK", "FOR",
  "CONTINUE", "IF", "ELSE", "DO", "WHILE", "THIS", "EVAL", "TIME",
  "RANDOM", "LENGTH", "INT", "CONCAT", "DUPLICATECLIP", "REMOVECLIP",
  "TRACE", "STARTDRAG", "STOPDRAG", "ORD", "CHR", "CALLFRAME", "GETURL",
  "GETURL1", "LOADMOVIE", "LOADMOVIENUM", "LOADVARIABLES", "POSTURL",
  "SUBSTR", "GETPROPERTY", "NEXTFRAME", "PREVFRAME", "PLAY", "STOP",
  "TOGGLEQUALITY", "STOPSOUNDS", "GOTOFRAME", "GOTOANDPLAY", "FRAMELOADED",
  "SETTARGET", "ASM", "ASMADD", "ASMDIVIDE", "ASMMULTIPLY", "ASMEQUALS",
  "ASMLESS", "ASMLOGICALAND", "ASMLOGICALOR", "ASMLOGICALNOT",
  "ASMSTRINGAND", "ASMSTRINGEQUALS", "ASMSTRINGEXTRACT", "ASMSTRINGLENGTH",
  "ASMMBSTRINGEXTRACT", "ASMMBSTRINGLENGTH", "ASMPOP", "ASMPUSH",
  "ASMASCIITOCHAR", "ASMCHARTOASCII", "ASMTOINTEGER", "ASMCALL", "ASMIF",
  "ASMJUMP", "ASMGETVARIABLE", "ASMSETVARIABLE", "ASMGETURL2",
  "ASMGETPROPERTY", "ASMGOTOFRAME2", "ASMREMOVESPRITE", "ASMSETPROPERTY",
  "ASMSETTARGET2", "ASMSTARTDRAG", "ASMWAITFORFRAME2", "ASMCLONESPRITE",
  "ASMENDDRAG", "ASMGETTIME", "ASMRANDOMNUMBER", "ASMTRACE",
  "ASMMBASCIITOCHAR", "ASMMBCHARTOASCII", "ASMSUBSTRACT", "ASMSTRINGLESS",
  "TELLTARGET", "BROKENSTRING", "STRING", "NUMBER", "IDENTIFIER", "PATH",
  "\"==\"", "\"<=\"", "\">=\"", "\"!=\"", "\"&&\"", "\"||\"", "\"++\"",
  "\"--\"", "\"+=\"", "\"/=\"", "\"*=\"", "\"-=\"", "\"===\"", "\"!==\"",
  "\"<=>\"", "\"..\"", "\"end\"", "','", "'='", "'?'", "':'", "'<'", "'>'",
  "'&'", "'+'", "'-'", "'*'", "'/'", "UMINUS", "'!'", "POSTFIX", "NEGATE",
  "'{'", "'}'", "';'", "'('", "')'", "'.'", "$accept", "program", "elems",
  "elem", "stmt", "assign_stmts", "statements", "if_stmt", "expr_opt",
  "iter_stmt", "assign_stmts_opt", "cont_stmt", "break_stmt", "urlmethod",
  "level", "void_function_call", "function_call", "pf_expr", "rhs_expr",
  "variable", "sprite", "lhs_expr", "assign_stmt", "$@1", "expr",
  "push_item", "push_list", "opcode_list", "opcode", "@2", YY_NULLPTR
};

static const char *
yysymbol_name (yysymbol_kind_t yysymbol)
{
  return yytname[yysymbol];
}
#endif

#define YYPACT_NINF (-325)

#define yypact_value_is_default(Yyn) \
  ((Yyn) == YYPACT_NINF)

#define YYTABLE_NINF (-123)

#define yytable_value_is_error(Yyn) \
  0

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
static const yytype_int16 yypact[] =
{
     829,  -118,  -110,   -93,  -109,   829,   -98,  -325,   -86,   -80,
     -79,   -76,   -72,   -71,   -64,   -61,   -57,   -56,   -48,   -47,
     -39,   -38,   -30,   -26,   -25,   -21,   -20,   -19,   -15,   -17,
    -325,   -77,  -325,     8,     8,  -325,  -325,   577,  -325,  1122,
    -325,    84,   829,  -325,  -325,  -325,  -325,  -325,  -325,  -325,
    -325,  -325,   -99,   104,   -40,  -325,   941,  -325,   975,   101,
    1221,  1122,  1122,  1122,  1122,   -14,    -7,  1122,    25,  1122,
    1122,  1122,   -12,   -11,    -5,    -4,    -3,    -2,  1245,  1122,
    1269,  -325,  1368,   -97,  -325,   -90,  -325,  -325,  -325,   703,
      -6,     1,     2,     4,     5,     9,    17,    18,    19,    20,
      38,  -325,     8,     8,  1392,  1122,  1122,  -325,    46,    39,
     -89,    43,  -325,  -325,    64,    65,  -325,  -325,  1122,  1122,
    1122,  1122,  1122,  -325,    47,    41,  -325,    42,  1074,   419,
      44,    48,  1098,    45,    57,    53,    54,    59,  -325,    56,
      60,    58,    62,    80,    81,    82,    83,  -325,  -325,  -325,
    -325,  -325,  -325,  -108,    69,    71,    87,  -101,    89,  1600,
    -100,    90,   103,   118,  -325,  -325,  1122,   100,  1122,  1122,
    1122,  1122,  1122,  1122,  1122,  1122,   -87,  -325,   -75,  -325,
    -325,  -325,  -325,   259,  1122,  1122,  1122,  1122,  1122,  1122,
    1122,  1122,  1122,  1122,  1122,  1122,  1122,  1122,  1122,  1122,
    1122,  -325,   119,  1122,  -325,   -41,   419,   419,   419,   419,
     419,   941,  1122,  1416,   102,   829,  1122,   105,   829,  1122,
    -325,  -325,  1122,  -325,  -325,  1122,   122,  1122,  1122,  1122,
    -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,
    -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,
    -325,  -325,  -325,  -325,  -325,  -325,   141,   144,  -325,  -325,
     146,  -325,   147,  -325,  -325,  -325,  -325,   148,  -325,  -325,
    -325,  -325,  -325,  -325,  -325,  -325,  -325,  1504,  -325,   829,
     829,  -325,  -325,   110,  -325,   111,   112,   113,   134,   116,
     117,   138,   139,   121,   167,   150,   107,   -24,   -24,   107,
     530,   530,   107,   107,   -24,   158,   -24,   -24,   -42,   -74,
     -74,  -325,  -325,  -325,   419,  1122,  1122,  1122,  1122,  1122,
    -325,   132,  -325,   133,   137,  1515,   258,   140,   178,  -325,
     169,  -104,  -102,   151,   174,   174,  -325,   174,   204,  -325,
    -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,  -325,
    -325,  -325,  1122,  -325,  -325,  1122,   205,  -325,  -325,  1122,
     419,   419,   419,   419,   419,   941,   166,   170,   171,   172,
     829,  -325,   173,  1122,  1122,  -325,   209,  -325,   175,  -325,
     176,   177,   179,  -325,  -325,   193,   180,   197,   181,   419,
     185,   829,   829,   186,   187,  -325,   188,   189,   210,  -325,
    -325,  -325,  -325,  -325,   204,  -325,  1122,  -325,   829,   310,
     314,   829,   829,   829,  -325,  1122,  -325,   195,  -325,   829,
     829,  -325,  -325,  -325,   215,  -325,  -325,  -325,  1122,   216,
    1122,   198,  -325
};

/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE does not specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       0,     0,     0,     0,     0,     0,     0,   114,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     121,   112,   119,     0,     0,   117,   116,     0,     8,     0,
     115,     0,     2,     3,     5,    10,    11,    12,    13,   126,
     123,   120,     0,     0,     0,    36,    33,    35,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   124,     0,     0,   127,     0,   128,     6,    17,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      84,    82,     0,     0,     0,     0,     0,    80,     0,    85,
      86,     0,     1,     4,     0,     0,    78,    79,     0,     0,
       0,     0,     0,     9,    34,     0,    14,     0,     0,   141,
       0,     0,     0,     0,     0,     0,     0,     0,    40,     0,
       0,     0,     0,     0,     0,     0,     0,    54,    55,    56,
      57,    58,    59,    84,    82,     0,     0,    84,     0,     0,
      84,     0,     0,     0,     7,    18,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    89,     0,    91,
      82,    92,    93,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   122,     0,     0,   113,     0,   134,   133,   132,   135,
     131,     0,    27,     0,     0,     0,     0,     0,     0,     0,
      43,    44,     0,    42,    41,     0,     0,     0,     0,     0,
      61,    60,    62,    63,    64,    65,   149,   152,   151,   153,
     154,   155,   156,   157,   158,   159,   161,   160,   162,   163,
     165,   147,   166,   167,   168,   171,     0,     0,   172,   173,
       0,   174,     0,   176,   175,   177,   178,     0,   180,   179,
     181,   182,   183,   169,   170,   150,   164,     0,   145,     0,
       0,   129,   130,     0,    69,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,    81,   107,   102,   103,   108,
     109,   110,   105,   104,   106,     0,   100,   101,    99,    97,
      98,    95,    96,    87,    94,     0,     0,     0,     0,     0,
      15,     0,    28,    82,     0,     0,    26,     0,     0,    30,
       0,     0,     0,     0,    37,    37,    39,    37,     0,   184,
     185,   186,   187,   188,   125,   146,    66,    67,    68,    70,
      71,    72,     0,    73,    74,     0,     0,    88,    90,     0,
     139,   138,   137,   140,   136,    33,     0,     0,    82,     0,
       0,    31,     0,     0,     0,    51,     0,    45,     0,    47,
       0,     0,     0,   142,   143,   148,     0,     0,     0,   111,
       0,     0,     0,     0,     0,    25,     0,     0,     0,    38,
      46,    48,    49,    50,     0,    75,     0,    77,     0,    20,
      23,     0,     0,     0,    53,     0,   144,     0,    32,     0,
       0,    21,    24,    29,     0,    76,    19,    22,     0,     0,
       0,     0,    52
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -325,  -325,  -325,   284,    40,  -325,  -325,  -325,  -325,  -325,
     -36,  -325,  -325,  -324,  -325,  -325,  -325,  -325,   375,     0,
      15,    30,   -54,  -325,   115,   -69,  -325,  -325,    55,  -325
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
       0,    41,    42,    43,    44,   124,    89,    45,   321,    46,
     125,    47,    48,   378,   335,    49,   107,    50,   129,   109,
     110,   111,    54,   159,   130,   384,   385,   277,   278,   338
};

/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule whose
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
      51,  -121,   126,     7,   374,    51,   376,    55,  -121,  -121,
     380,   381,   114,   382,   114,    52,    56,    58,     7,   230,
      52,   114,   114,   375,   114,   377,   234,   279,    60,   115,
      53,   162,    57,    51,    51,    53,   114,    51,   163,   202,
      61,   293,    51,   199,   200,    59,    62,    63,    83,    85,
      64,  -118,    52,   294,    65,    66,    51,    52,   315,   316,
     317,   318,    67,    84,    86,    68,   140,    53,   319,    69,
      70,    52,    53,   197,   198,   199,   200,    88,    71,    72,
     139,   141,    31,    32,   112,   123,    53,    73,    74,    51,
     196,   197,   198,   199,   200,    30,    75,    31,    32,    35,
      76,    77,    51,    51,    52,    78,    79,    80,    81,    82,
     131,    36,   143,   138,    35,   147,   148,   176,   178,    53,
     166,    40,   149,   150,   151,   152,    36,   167,   168,   165,
     169,   170,   177,   179,    39,   171,    40,   184,   185,   186,
     187,   188,   189,   172,   173,   174,   175,  -121,  -120,   190,
     191,   192,   203,   204,   205,   211,   193,   320,   194,   195,
     196,   197,   198,   199,   200,   219,   212,   222,   213,   114,
     225,   215,   218,   201,   216,   133,   134,   135,   136,   137,
     220,   221,   142,   223,   144,   145,   146,   224,   226,   227,
     228,   229,   281,   155,   156,   158,   231,   161,   232,   185,
     186,   116,   117,   118,   119,   120,   121,   282,   313,   333,
     357,    51,   192,   122,   233,    51,   235,   280,    51,   194,
     195,   196,   197,   198,   199,   200,    52,   284,   325,   339,
      52,   328,   340,    52,   341,   342,   343,   348,   349,   350,
     351,    53,   352,   353,   354,    53,   355,   356,    53,   184,
     185,   186,   187,   188,   189,   326,   358,   365,   329,  -122,
     366,   190,   191,   192,   367,   370,   372,   371,   193,   359,
     194,   195,   196,   197,   198,   199,   200,   373,   379,    51,
      51,   283,   376,   285,   286,   287,   288,   289,   290,   291,
     292,   383,   388,   391,    52,    52,   399,   392,   393,   394,
     396,   404,   400,   401,   402,   406,   403,   405,   407,    53,
      53,   126,   408,   411,   412,   413,   414,   419,   415,   346,
     347,   420,   425,   428,   430,   432,   113,   322,   324,   390,
       0,   327,   345,     0,   330,   416,     0,   331,     0,     0,
     332,     0,   334,   336,   337,     0,     0,     0,     0,     0,
     184,   185,   186,   187,   188,   189,     0,     0,     0,     0,
       0,     0,   190,   191,   192,    51,     0,     0,     0,   193,
      51,   194,   195,   196,   197,   198,   199,   200,     0,     0,
      52,     0,     0,     0,     0,    52,   295,     0,     0,     0,
       0,    51,    51,     0,     0,    53,     0,     0,     0,     0,
      53,     0,     0,     0,     0,     0,    52,    52,    51,     0,
     395,    51,    51,    51,   108,     0,     0,     0,     0,    51,
      51,    53,    53,    52,     0,     0,    52,    52,    52,     0,
       0,   409,   410,     0,    52,    52,     0,     0,    53,     0,
     369,    53,    53,    53,     0,     0,     0,     0,   418,    53,
      53,   421,   422,   423,     0,     0,     0,     0,     0,   426,
     427,     0,     0,     0,     0,     0,     0,   386,     0,     0,
     387,     0,     0,     0,     0,     0,     0,     0,     0,   181,
     182,   183,     0,     0,     0,     0,     0,     0,   397,   398,
       0,     0,     0,   206,   207,   208,   209,   210,     0,     0,
       0,     0,     0,   182,     0,     0,     0,   182,     0,     0,
     184,   185,   186,   187,   188,   189,     0,     0,     0,     0,
       0,   417,   190,   191,   192,     0,     0,     0,     0,   193,
     424,   194,   195,   196,   197,   198,   199,   200,     0,     0,
       0,     0,     0,   429,     0,   431,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   296,
     297,   298,   299,   300,   301,   302,   303,   304,   305,   306,
     307,   308,   309,   310,   311,   312,     0,     0,   314,     0,
       1,     2,     3,     4,     0,     5,     6,     7,     0,     0,
       0,     0,     0,     0,     8,     9,    10,    11,    12,     0,
       0,    13,    14,    15,    16,    17,    18,     0,     0,     0,
      19,    20,    21,    22,    23,    24,    25,    26,     0,    27,
      28,   184,   185,   186,   187,     0,     0,     0,     0,     0,
       0,     0,     0,   190,   191,   192,     0,     0,     0,     0,
       0,     0,   194,   195,   196,   197,   198,   199,   200,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,    29,     0,    30,     0,    31,    32,     0,     0,
       0,     0,     0,     0,    33,    34,     0,     0,     0,     0,
       0,     0,     0,    35,     0,     0,     0,     0,     0,     0,
     360,   361,   362,   363,   364,    36,     0,     0,     0,     0,
      37,    87,    38,    39,     0,    40,     1,     2,     3,     4,
       0,     5,     6,     7,     0,     0,     0,     0,     0,     0,
       8,     9,    10,    11,    12,     0,     0,    13,    14,    15,
      16,    17,    18,     0,   389,     0,    19,    20,    21,    22,
      23,    24,    25,    26,     0,    27,    28,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    29,     0,
      30,     0,    31,    32,     0,     0,     0,     0,     0,     0,
      33,    34,     0,     0,     0,     0,     0,     0,     0,    35,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,    36,     0,     0,     0,     0,    37,   164,    38,    39,
       0,    40,     1,     2,     3,     4,     0,     5,     6,     7,
       0,     0,     0,     0,     0,     0,     8,     9,    10,    11,
      12,     0,     0,    13,    14,    15,    16,    17,    18,     0,
       0,     0,    19,    20,    21,    22,    23,    24,    25,    26,
       0,    27,    28,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,    29,     0,    30,     0,    31,    32,
       0,     0,     0,     0,     0,     0,    33,    34,     0,     0,
       0,     0,     0,     0,     0,    35,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    36,     0,     0,
       0,     7,    37,     0,    38,    39,     0,    40,     8,     9,
      10,    11,    12,     0,     0,    13,    14,    15,    16,    17,
      18,     0,     0,     0,    19,    20,    21,    22,    23,    24,
      25,    26,     0,    27,    28,     7,    90,    91,    92,    93,
      94,    95,     0,     0,     0,     0,     0,    96,    97,     0,
       0,     0,     0,     0,     0,     0,    98,    99,     0,     0,
       0,     0,     0,     0,     0,     0,   127,     0,     0,     0,
       0,     0,     0,     0,     0,     0,    29,     0,    30,     0,
      31,    32,     0,     0,     0,     0,     0,     0,    33,    34,
       0,     0,     0,     0,     0,     0,     0,    35,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,    36,
       0,     0,   100,   101,    31,    32,     0,    39,     0,    40,
       0,     0,   102,   103,     0,     0,     0,     0,     0,     0,
       0,    35,     0,     0,     7,    90,    91,    92,    93,    94,
      95,   104,     0,    36,     0,   128,    96,    97,     0,     0,
       0,   106,     0,    40,     0,    98,    99,     0,     7,    90,
      91,    92,    93,    94,    95,   214,     0,     0,     0,     0,
      96,    97,     0,     0,     0,     0,     0,     0,     0,    98,
      99,     0,     7,    90,    91,    92,    93,    94,    95,   217,
       0,     0,     0,     0,    96,    97,     0,     0,     0,     0,
       0,     0,     0,    98,    99,     0,     0,     0,     0,     0,
       0,   100,   101,    31,    32,     0,     0,     0,     0,     0,
       0,   102,   103,     0,     0,     0,     0,     0,     0,     0,
      35,     0,     0,     0,     0,   100,   101,    31,    32,     0,
     104,     0,    36,     0,   105,   102,   103,     0,     0,     0,
     106,     0,    40,     0,    35,     0,     0,     0,     0,   100,
     101,    31,    32,     0,   104,     0,    36,     0,   105,   102,
     103,     0,     0,     0,   106,     0,    40,     0,    35,     0,
       0,     7,    90,    91,    92,    93,    94,    95,   104,     0,
      36,     0,   105,    96,    97,     0,     0,     0,   106,     0,
      40,     0,    98,    99,     0,     7,    90,    91,    92,    93,
      94,    95,     0,     0,     0,     0,     0,    96,    97,     0,
       0,     0,     0,     0,     0,     0,    98,    99,     0,     7,
      90,    91,    92,    93,    94,    95,     0,     0,     0,     0,
       0,    96,    97,     0,     0,     0,     0,     0,     0,     0,
      98,    99,     0,     0,     0,     0,     0,     0,   100,   101,
      31,    32,     0,     0,     0,     0,     0,     0,   102,   103,
       0,     0,     0,     0,     0,     0,     0,    35,     0,     0,
       0,     0,   153,   154,    31,    32,     0,   104,     0,    36,
       0,   132,   102,   103,     0,     0,     0,   106,     0,    40,
       0,    35,     0,     0,     0,     0,   157,   101,    31,    32,
       0,   104,     0,    36,     0,   105,   102,   103,     0,     0,
       0,   106,     0,    40,     0,    35,     0,     0,     7,    90,
      91,    92,    93,    94,    95,   104,     0,    36,     0,   105,
      96,    97,     0,     0,     0,   106,     0,    40,     0,    98,
      99,     0,     7,    90,    91,    92,    93,    94,    95,     0,
       0,     0,     0,     0,    96,    97,     0,     0,     0,     0,
       0,     0,     0,    98,    99,     0,     7,    90,    91,    92,
      93,    94,    95,     0,     0,     0,     0,     0,    96,    97,
       0,     0,     0,     0,     0,     0,     0,    98,    99,     0,
       0,     0,     0,     0,     0,   160,   101,    31,    32,     0,
       0,     0,     0,     0,     0,   102,   103,     0,     0,     0,
       0,     0,     0,     0,    35,     0,     0,     0,     0,   100,
     180,    31,    32,     0,   104,     0,    36,     0,   105,   102,
     103,     0,     0,     0,   106,     0,    40,     0,    35,     0,
       0,     0,     0,   100,   323,    31,    32,     0,   104,     0,
      36,     0,   105,   102,   103,     0,     0,     0,   106,     0,
      40,     0,    35,     0,     0,     7,    90,    91,    92,    93,
      94,    95,   104,     0,    36,     0,   105,    96,    97,     0,
       0,     0,   106,     0,    40,     0,    98,    99,   236,   237,
     238,   239,   240,   241,   242,   243,   244,   245,   246,   247,
     248,   249,   250,   251,   252,   253,   254,   255,   256,   257,
     258,   259,   260,   261,   262,   263,   264,   265,   266,   267,
     268,   269,   270,   271,   272,   273,   274,   275,   276,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   100,   368,    31,    32,     0,     0,     0,     0,
       0,     0,   102,   103,     0,     0,     0,     0,     0,     0,
       0,    35,     0,     0,     0,     0,     0,     0,   344,     0,
       0,   104,     0,    36,     0,   105,     0,     0,     0,     0,
       0,   106,     0,    40,   236,   237,   238,   239,   240,   241,
     242,   243,   244,   245,   246,   247,   248,   249,   250,   251,
     252,   253,   254,   255,   256,   257,   258,   259,   260,   261,
     262,   263,   264,   265,   266,   267,   268,   269,   270,   271,
     272,   273,   274,   275,   276
};

static const yytype_int16 yycheck[] =
{
       0,   109,    56,    10,   108,     5,   108,   125,   109,   109,
     334,   335,   111,   337,   111,     0,   126,   126,    10,   127,
       5,   111,   111,   127,   111,   127,   127,   127,   126,   128,
       0,   128,   125,    33,    34,     5,   111,    37,   128,   128,
     126,   128,    42,   117,   118,     5,   126,   126,    33,    34,
     126,   128,    37,   128,   126,   126,    56,    42,    99,   100,
     101,   102,   126,    33,    34,   126,    66,    37,   109,   126,
     126,    56,    42,   115,   116,   117,   118,    37,   126,   126,
      87,    66,    89,    90,     0,   125,    56,   126,   126,    89,
     114,   115,   116,   117,   118,    87,   126,    89,    90,   106,
     126,   126,   102,   103,    89,   126,   126,   126,   123,   126,
       9,   118,    87,   127,   106,   127,   127,   102,   103,    89,
     126,   128,   127,   127,   127,   127,   118,   126,   126,    89,
     126,   126,   102,   103,   126,   126,   128,    91,    92,    93,
      94,    95,    96,   126,   126,   126,   126,   109,   109,   103,
     104,   105,   109,    89,    89,   108,   110,   211,   112,   113,
     114,   115,   116,   117,   118,   108,   125,   108,   126,   111,
     108,   127,   127,   127,   126,    60,    61,    62,    63,    64,
     127,   127,    67,   127,    69,    70,    71,   127,   108,   108,
     108,   108,    89,    78,    79,    80,   127,    82,   127,    92,
      93,    97,    98,    99,   100,   101,   102,    89,    89,    87,
      89,   211,   105,   109,   127,   215,   127,   127,   218,   112,
     113,   114,   115,   116,   117,   118,   211,   127,   126,    88,
     215,   126,    88,   218,    88,    88,    88,   127,   127,   127,
     127,   211,   108,   127,   127,   215,   108,   108,   218,    91,
      92,    93,    94,    95,    96,   215,    89,   125,   218,   109,
     127,   103,   104,   105,   127,     7,    88,   127,   110,   111,
     112,   113,   114,   115,   116,   117,   118,   108,   127,   279,
     280,   166,   108,   168,   169,   170,   171,   172,   173,   174,
     175,    87,    87,   127,   279,   280,    87,   127,   127,   127,
     127,   108,   127,   127,   127,   108,   127,   127,   127,   279,
     280,   365,   127,   127,   127,   127,   127,     7,   108,   279,
     280,     7,   127,   108,   108,   127,    42,   212,   213,   365,
      -1,   216,   277,    -1,   219,   404,    -1,   222,    -1,    -1,
     225,    -1,   227,   228,   229,    -1,    -1,    -1,    -1,    -1,
      91,    92,    93,    94,    95,    96,    -1,    -1,    -1,    -1,
      -1,    -1,   103,   104,   105,   365,    -1,    -1,    -1,   110,
     370,   112,   113,   114,   115,   116,   117,   118,    -1,    -1,
     365,    -1,    -1,    -1,    -1,   370,   127,    -1,    -1,    -1,
      -1,   391,   392,    -1,    -1,   365,    -1,    -1,    -1,    -1,
     370,    -1,    -1,    -1,    -1,    -1,   391,   392,   408,    -1,
     370,   411,   412,   413,    39,    -1,    -1,    -1,    -1,   419,
     420,   391,   392,   408,    -1,    -1,   411,   412,   413,    -1,
      -1,   391,   392,    -1,   419,   420,    -1,    -1,   408,    -1,
     325,   411,   412,   413,    -1,    -1,    -1,    -1,   408,   419,
     420,   411,   412,   413,    -1,    -1,    -1,    -1,    -1,   419,
     420,    -1,    -1,    -1,    -1,    -1,    -1,   352,    -1,    -1,
     355,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   104,
     105,   106,    -1,    -1,    -1,    -1,    -1,    -1,   373,   374,
      -1,    -1,    -1,   118,   119,   120,   121,   122,    -1,    -1,
      -1,    -1,    -1,   128,    -1,    -1,    -1,   132,    -1,    -1,
      91,    92,    93,    94,    95,    96,    -1,    -1,    -1,    -1,
      -1,   406,   103,   104,   105,    -1,    -1,    -1,    -1,   110,
     415,   112,   113,   114,   115,   116,   117,   118,    -1,    -1,
      -1,    -1,    -1,   428,    -1,   430,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   184,
     185,   186,   187,   188,   189,   190,   191,   192,   193,   194,
     195,   196,   197,   198,   199,   200,    -1,    -1,   203,    -1,
       3,     4,     5,     6,    -1,     8,     9,    10,    -1,    -1,
      -1,    -1,    -1,    -1,    17,    18,    19,    20,    21,    -1,
      -1,    24,    25,    26,    27,    28,    29,    -1,    -1,    -1,
      33,    34,    35,    36,    37,    38,    39,    40,    -1,    42,
      43,    91,    92,    93,    94,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   103,   104,   105,    -1,    -1,    -1,    -1,
      -1,    -1,   112,   113,   114,   115,   116,   117,   118,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    85,    -1,    87,    -1,    89,    90,    -1,    -1,
      -1,    -1,    -1,    -1,    97,    98,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   106,    -1,    -1,    -1,    -1,    -1,    -1,
     315,   316,   317,   318,   319,   118,    -1,    -1,    -1,    -1,
     123,   124,   125,   126,    -1,   128,     3,     4,     5,     6,
      -1,     8,     9,    10,    -1,    -1,    -1,    -1,    -1,    -1,
      17,    18,    19,    20,    21,    -1,    -1,    24,    25,    26,
      27,    28,    29,    -1,   359,    -1,    33,    34,    35,    36,
      37,    38,    39,    40,    -1,    42,    43,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    85,    -1,
      87,    -1,    89,    90,    -1,    -1,    -1,    -1,    -1,    -1,
      97,    98,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   106,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   118,    -1,    -1,    -1,    -1,   123,   124,   125,   126,
      -1,   128,     3,     4,     5,     6,    -1,     8,     9,    10,
      -1,    -1,    -1,    -1,    -1,    -1,    17,    18,    19,    20,
      21,    -1,    -1,    24,    25,    26,    27,    28,    29,    -1,
      -1,    -1,    33,    34,    35,    36,    37,    38,    39,    40,
      -1,    42,    43,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    85,    -1,    87,    -1,    89,    90,
      -1,    -1,    -1,    -1,    -1,    -1,    97,    98,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,   106,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,   118,    -1,    -1,
      -1,    10,   123,    -1,   125,   126,    -1,   128,    17,    18,
      19,    20,    21,    -1,    -1,    24,    25,    26,    27,    28,
      29,    -1,    -1,    -1,    33,    34,    35,    36,    37,    38,
      39,    40,    -1,    42,    43,    10,    11,    12,    13,    14,
      15,    16,    -1,    -1,    -1,    -1,    -1,    22,    23,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    31,    32,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    41,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    85,    -1,    87,    -1,
      89,    90,    -1,    -1,    -1,    -1,    -1,    -1,    97,    98,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,   106,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   118,
      -1,    -1,    87,    88,    89,    90,    -1,   126,    -1,   128,
      -1,    -1,    97,    98,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   106,    -1,    -1,    10,    11,    12,    13,    14,    15,
      16,   116,    -1,   118,    -1,   120,    22,    23,    -1,    -1,
      -1,   126,    -1,   128,    -1,    31,    32,    -1,    10,    11,
      12,    13,    14,    15,    16,    41,    -1,    -1,    -1,    -1,
      22,    23,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    31,
      32,    -1,    10,    11,    12,    13,    14,    15,    16,    41,
      -1,    -1,    -1,    -1,    22,    23,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    31,    32,    -1,    -1,    -1,    -1,    -1,
      -1,    87,    88,    89,    90,    -1,    -1,    -1,    -1,    -1,
      -1,    97,    98,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
     106,    -1,    -1,    -1,    -1,    87,    88,    89,    90,    -1,
     116,    -1,   118,    -1,   120,    97,    98,    -1,    -1,    -1,
     126,    -1,   128,    -1,   106,    -1,    -1,    -1,    -1,    87,
      88,    89,    90,    -1,   116,    -1,   118,    -1,   120,    97,
      98,    -1,    -1,    -1,   126,    -1,   128,    -1,   106,    -1,
      -1,    10,    11,    12,    13,    14,    15,    16,   116,    -1,
     118,    -1,   120,    22,    23,    -1,    -1,    -1,   126,    -1,
     128,    -1,    31,    32,    -1,    10,    11,    12,    13,    14,
      15,    16,    -1,    -1,    -1,    -1,    -1,    22,    23,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    31,    32,    -1,    10,
      11,    12,    13,    14,    15,    16,    -1,    -1,    -1,    -1,
      -1,    22,    23,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      31,    32,    -1,    -1,    -1,    -1,    -1,    -1,    87,    88,
      89,    90,    -1,    -1,    -1,    -1,    -1,    -1,    97,    98,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,   106,    -1,    -1,
      -1,    -1,    87,    88,    89,    90,    -1,   116,    -1,   118,
      -1,   120,    97,    98,    -1,    -1,    -1,   126,    -1,   128,
      -1,   106,    -1,    -1,    -1,    -1,    87,    88,    89,    90,
      -1,   116,    -1,   118,    -1,   120,    97,    98,    -1,    -1,
      -1,   126,    -1,   128,    -1,   106,    -1,    -1,    10,    11,
      12,    13,    14,    15,    16,   116,    -1,   118,    -1,   120,
      22,    23,    -1,    -1,    -1,   126,    -1,   128,    -1,    31,
      32,    -1,    10,    11,    12,    13,    14,    15,    16,    -1,
      -1,    -1,    -1,    -1,    22,    23,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    31,    32,    -1,    10,    11,    12,    13,
      14,    15,    16,    -1,    -1,    -1,    -1,    -1,    22,    23,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    31,    32,    -1,
      -1,    -1,    -1,    -1,    -1,    87,    88,    89,    90,    -1,
      -1,    -1,    -1,    -1,    -1,    97,    98,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,   106,    -1,    -1,    -1,    -1,    87,
      88,    89,    90,    -1,   116,    -1,   118,    -1,   120,    97,
      98,    -1,    -1,    -1,   126,    -1,   128,    -1,   106,    -1,
      -1,    -1,    -1,    87,    88,    89,    90,    -1,   116,    -1,
     118,    -1,   120,    97,    98,    -1,    -1,    -1,   126,    -1,
     128,    -1,   106,    -1,    -1,    10,    11,    12,    13,    14,
      15,    16,   116,    -1,   118,    -1,   120,    22,    23,    -1,
      -1,    -1,   126,    -1,   128,    -1,    31,    32,    44,    45,
      46,    47,    48,    49,    50,    51,    52,    53,    54,    55,
      56,    57,    58,    59,    60,    61,    62,    63,    64,    65,
      66,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    87,    88,    89,    90,    -1,    -1,    -1,    -1,
      -1,    -1,    97,    98,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   106,    -1,    -1,    -1,    -1,    -1,    -1,   124,    -1,
      -1,   116,    -1,   118,    -1,   120,    -1,    -1,    -1,    -1,
      -1,   126,    -1,   128,    44,    45,    46,    47,    48,    49,
      50,    51,    52,    53,    54,    55,    56,    57,    58,    59,
      60,    61,    62,    63,    64,    65,    66,    67,    68,    69,
      70,    71,    72,    73,    74,    75,    76,    77,    78,    79,
      80,    81,    82,    83,    84
};

/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
   state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,     3,     4,     5,     6,     8,     9,    10,    17,    18,
      19,    20,    21,    24,    25,    26,    27,    28,    29,    33,
      34,    35,    36,    37,    38,    39,    40,    42,    43,    85,
      87,    89,    90,    97,    98,   106,   118,   123,   125,   126,
     128,   130,   131,   132,   133,   136,   138,   140,   141,   144,
     146,   148,   149,   150,   151,   125,   126,   125,   126,   133,
     126,   126,   126,   126,   126,   126,   126,   126,   126,   126,
     126,   126,   126,   126,   126,   126,   126,   126,   126,   126,
     126,   123,   126,   149,   150,   149,   150,   124,   133,   135,
      11,    12,    13,    14,    15,    16,    22,    23,    31,    32,
      87,    88,    97,    98,   116,   120,   126,   145,   147,   148,
     149,   150,     0,   132,   111,   128,    97,    98,    99,   100,
     101,   102,   109,   125,   134,   139,   151,    41,   120,   147,
     153,     9,   120,   153,   153,   153,   153,   153,   127,    87,
     148,   149,   153,    87,   153,   153,   153,   127,   127,   127,
     127,   127,   127,    87,    88,   153,   153,    87,   153,   152,
      87,   153,   128,   128,   124,   133,   126,   126,   126,   126,
     126,   126,   126,   126,   126,   126,   149,   150,   149,   150,
      88,   147,   147,   147,    91,    92,    93,    94,    95,    96,
     103,   104,   105,   110,   112,   113,   114,   115,   116,   117,
     118,   127,   128,   109,    89,    89,   147,   147,   147,   147,
     147,   108,   125,   126,    41,   127,   126,    41,   127,   108,
     127,   127,   108,   127,   127,   108,   108,   108,   108,   108,
     127,   127,   127,   127,   127,   127,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    55,    56,    57,
      58,    59,    60,    61,    62,    63,    64,    65,    66,    67,
      68,    69,    70,    71,    72,    73,    74,    75,    76,    77,
      78,    79,    80,    81,    82,    83,    84,   156,   157,   127,
     127,    89,    89,   153,   127,   153,   153,   153,   153,   153,
     153,   153,   153,   128,   128,   127,   147,   147,   147,   147,
     147,   147,   147,   147,   147,   147,   147,   147,   147,   147,
     147,   147,   147,    89,   147,    99,   100,   101,   102,   109,
     151,   137,   153,    88,   153,   126,   133,   153,   126,   133,
     153,   153,   153,    87,   153,   143,   153,   153,   158,    88,
      88,    88,    88,    88,   124,   157,   133,   133,   127,   127,
     127,   127,   108,   127,   127,   108,   108,    89,    89,   111,
     147,   147,   147,   147,   147,   125,   127,   127,    88,   153,
       7,   127,    88,   108,   108,   127,   108,   127,   142,   127,
     142,   142,   142,    87,   154,   155,   153,   153,    87,   147,
     139,   127,   127,   127,   127,   133,   127,   153,   153,    87,
     127,   127,   127,   127,   108,   127,   108,   127,   127,   133,
     133,   127,   127,   127,   127,   108,   154,   153,   133,     7,
       7,   133,   133,   133,   153,   127,   133,   133,   108,   153,
     108,   153,   127
};

/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
static const yytype_uint8 yyr1[] =
{
       0,   129,   130,   131,   131,   132,   133,   133,   133,   133,
     133,   133,   133,   133,   134,   134,   135,   135,   135,   136,
     136,   136,   136,   136,   136,   136,   136,   137,   137,   138,
     138,   138,   138,   139,   139,   140,   141,   142,   142,   143,
     144,   144,   144,   144,   144,   144,   144,   144,   144,   144,
     144,   144,   144,   144,   144,   144,   144,   144,   144,   144,
     144,   144,   144,   144,   144,   144,   144,   144,   145,   145,
     145,   145,   145,   145,   145,   145,   145,   145,   146,   146,
     147,   147,   147,   147,   147,   147,   147,   147,   147,   147,
     147,   147,   147,   147,   147,   147,   147,   147,   147,   147,
     147,   147,   147,   147,   147,   147,   147,   147,   147,   147,
     147,   147,   148,   148,   149,   149,   149,   149,   149,   149,
     150,   150,   150,   151,   152,   151,   151,   151,   151,   151,
     151,   151,   151,   151,   151,   151,   151,   151,   151,   151,
     151,   153,   154,   155,   155,   156,   156,   158,   157,   157,
     157,   157,   157,   157,   157,   157,   157,   157,   157,   157,
     157,   157,   157,   157,   157,   157,   157,   157,   157,   157,
     157,   157,   157,   157,   157,   157,   157,   157,   157,   157,
     157,   157,   157,   157,   157,   157,   157,   157,   157
};

/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr2[] =
{
       0,     2,     1,     1,     2,     1,     2,     3,     1,     2,
       1,     1,     1,     1,     1,     3,     0,     1,     2,    10,
       8,     9,    10,     8,     9,     7,     5,     0,     1,     9,
       5,     6,     9,     0,     1,     2,     2,     0,     2,     1,
       3,     4,     4,     4,     4,     6,     7,     6,     7,     7,
       7,     6,    14,     8,     3,     3,     3,     3,     3,     3,
       4,     4,     4,     4,     4,     4,     5,     5,     4,     3,
       4,     4,     4,     4,     4,     6,     8,     6,     2,     2,
       1,     3,     1,     2,     1,     1,     1,     3,     4,     2,
       4,     2,     2,     2,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     5,     1,     3,     1,     1,     1,     1,     1,     1,
       1,     1,     3,     1,     0,     5,     1,     2,     2,     4,
       4,     3,     3,     3,     3,     3,     5,     5,     5,     5,
       5,     1,     1,     1,     3,     1,     2,     0,     3,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     2,     2,     2,     2,     2
};


enum { YYENOMEM = -2 };

#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYNOMEM         goto yyexhaustedlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                    \
  do                                                              \
    if (yychar == YYEMPTY)                                        \
      {                                                           \
        yychar = (Token);                                         \
        yylval = (Value);                                         \
        YYPOPSTACK (yylen);                                       \
        yystate = *yyssp;                                         \
        goto yybackup;                                            \
      }                                                           \
    else                                                          \
      {                                                           \
        yyerror (buffer, YY_("syntax error: cannot back up")); \
        YYERROR;                                                  \
      }                                                           \
  while (0)

/* Backward compatibility with an undocumented macro.
   Use YYerror or YYUNDEF. */
#define YYERRCODE YYUNDEF


/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)




# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Kind, Value, buffer); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*-----------------------------------.
| Print this symbol's value on YYO.  |
`-----------------------------------*/

static void
yy_symbol_value_print (FILE *yyo,
                       yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep, void *buffer)
{
  FILE *yyoutput = yyo;
  YY_USE (yyoutput);
  YY_USE (buffer);
  if (!yyvaluep)
    return;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/*---------------------------.
| Print this symbol on YYO.  |
`---------------------------*/

static void
yy_symbol_print (FILE *yyo,
                 yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep, void *buffer)
{
  YYFPRINTF (yyo, "%s %s (",
             yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));

  yy_symbol_value_print (yyo, yykind, yyvaluep, buffer);
  YYFPRINTF (yyo, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp,
                 int yyrule, void *buffer)
{
  int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       YY_ACCESSING_SYMBOL (+yyssp[yyi + 1 - yynrhs]),
                       &yyvsp[(yyi + 1) - (yynrhs)], buffer);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule, buffer); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args) ((void) 0)
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif






/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg,
            yysymbol_kind_t yykind, YYSTYPE *yyvaluep, void *buffer)
{
  YY_USE (yyvaluep);
  YY_USE (buffer);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/* Lookahead token kind.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;




/*----------.
| yyparse.  |
`----------*/

int
yyparse (void *buffer)
{
    yy_state_fast_t yystate = 0;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus = 0;

    /* Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* Their size.  */
    YYPTRDIFF_T yystacksize = YYINITDEPTH;

    /* The state stack: array, bottom, top.  */
    yy_state_t yyssa[YYINITDEPTH];
    yy_state_t *yyss = yyssa;
    yy_state_t *yyssp = yyss;

    /* The semantic value stack: array, bottom, top.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs = yyvsa;
    YYSTYPE *yyvsp = yyvs;

  int yyn;
  /* The return value of yyparse.  */
  int yyresult;
  /* Lookahead symbol kind.  */
  yysymbol_kind_t yytoken = YYSYMBOL_YYEMPTY;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;



#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yychar = YYEMPTY; /* Cause a token to be read.  */

  goto yysetstate;


/*------------------------------------------------------------.
| yynewstate -- push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;


/*--------------------------------------------------------------------.
| yysetstate -- set current state (the top of the stack) to yystate.  |
`--------------------------------------------------------------------*/
yysetstate:
  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
  YY_IGNORE_USELESS_CAST_BEGIN
  *yyssp = YY_CAST (yy_state_t, yystate);
  YY_IGNORE_USELESS_CAST_END
  YY_STACK_PRINT (yyss, yyssp);

  if (yyss + yystacksize - 1 <= yyssp)
#if !defined yyoverflow && !defined YYSTACK_RELOCATE
    YYNOMEM;
#else
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYPTRDIFF_T yysize = yyssp - yyss + 1;

# if defined yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        yy_state_t *yyss1 = yyss;
        YYSTYPE *yyvs1 = yyvs;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * YYSIZEOF (*yyssp),
                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                    &yystacksize);
        yyss = yyss1;
        yyvs = yyvs1;
      }
# else /* defined YYSTACK_RELOCATE */
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        YYNOMEM;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yy_state_t *yyss1 = yyss;
        union yyalloc *yyptr =
          YY_CAST (union yyalloc *,
                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
        if (! yyptr)
          YYNOMEM;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YY_IGNORE_USELESS_CAST_BEGIN
      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
                  YY_CAST (long, yystacksize)));
      YY_IGNORE_USELESS_CAST_END

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }
#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */


  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;


/*-----------.
| yybackup.  |
`-----------*/
yybackup:
  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token\n"));
      yychar = yylex ();
    }

  if (yychar <= YYEOF)
    {
      yychar = YYEOF;
      yytoken = YYSYMBOL_YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else if (yychar == YYerror)
    {
      /* The scanner already issued an error message, process directly
         to error recovery.  But do not keep the error token as
         lookahead, it is too special and may lead us to an endless
         loop in error recovery. */
      yychar = YYUNDEF;
      yytoken = YYSYMBOL_YYerror;
      goto yyerrlab1;
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  /* Discard the shifted token.  */
  yychar = YYEMPTY;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
  case 2: /* program: elems  */
#line 165 "./swf4compiler.y"
                { *((Buffer *)buffer) = (yyvsp[0].action); }
#line 1784 "swf4compiler.tab.c"
    break;

  case 4: /* elems: elems elem  */
#line 172 "./swf4compiler.y"
                { bufferConcat((yyvsp[-1].action), (yyvsp[0].action)); }
#line 1790 "swf4compiler.tab.c"
    break;

  case 6: /* stmt: '{' '}'  */
#line 180 "./swf4compiler.y"
                                                { (yyval.action) = NULL; }
#line 1796 "swf4compiler.tab.c"
    break;

  case 7: /* stmt: '{' statements '}'  */
#line 181 "./swf4compiler.y"
                                                { (yyval.action) = (yyvsp[-1].action); }
#line 1802 "swf4compiler.tab.c"
    break;

  case 8: /* stmt: ';'  */
#line 182 "./swf4compiler.y"
                                                { (yyval.action) = NULL; }
#line 1808 "swf4compiler.tab.c"
    break;

  case 15: /* assign_stmts: assign_stmts ',' assign_stmt  */
#line 192 "./swf4compiler.y"
                                                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action)); }
#line 1814 "swf4compiler.tab.c"
    break;

  case 16: /* statements: %empty  */
#line 196 "./swf4compiler.y"
                        { (yyval.action) = NULL; }
#line 1820 "swf4compiler.tab.c"
    break;

  case 18: /* statements: statements stmt  */
#line 199 "./swf4compiler.y"
                        { bufferConcat((yyvsp[-1].action), (yyvsp[0].action)); }
#line 1826 "swf4compiler.tab.c"
    break;

  case 19: /* if_stmt: IF '(' FRAMELOADED '(' NUMBER ')' ')' stmt ELSE stmt  */
#line 206 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_WAITFORFRAME);
		  bufferWriteS16((yyval.action), 3);
		  bufferWriteS16((yyval.action), atoi((yyvsp[-5].str)));
		  free((yyvsp[-5].str));
		  bufferWriteU8((yyval.action), 1);		/* if not loaded, jump to.. */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action))+5);
		  bufferConcat((yyval.action), (yyvsp[0].action));			  /* ..here */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[-2].action)));
		  bufferConcat((yyval.action), (yyvsp[-2].action)); }
#line 1845 "swf4compiler.tab.c"
    break;

  case 20: /* if_stmt: IF '(' FRAMELOADED '(' NUMBER ')' ')' stmt  */
#line 222 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_WAITFORFRAME);
		  bufferWriteS16((yyval.action), 3);
		  bufferWriteS16((yyval.action), atoi((yyvsp[-3].str)));
		  free((yyvsp[-3].str));
		  bufferWriteU8((yyval.action), 1);		/* if not loaded, jump to.. */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), 5);
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);	  /* ..here */
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action)));	  /* ..and then out */
		  bufferConcat((yyval.action), (yyvsp[0].action)); }
#line 1863 "swf4compiler.tab.c"
    break;

  case 21: /* if_stmt: IF '(' '!' FRAMELOADED '(' NUMBER ')' ')' stmt  */
#line 238 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_WAITFORFRAME);
		  bufferWriteS16((yyval.action), 3);
		  bufferWriteS16((yyval.action), atoi((yyvsp[-3].str)));
		  free((yyvsp[-3].str));
		  bufferWriteU8((yyval.action), 1);		/* if not loaded, jump to.. */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action)));
		  bufferConcat((yyval.action), (yyvsp[0].action)); }
#line 1878 "swf4compiler.tab.c"
    break;

  case 22: /* if_stmt: IF '(' FRAMELOADED '(' expr ')' ')' stmt ELSE stmt  */
#line 250 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-5].action);
		  bufferWriteU8((yyval.action), SWFACTION_WAITFORFRAME2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 1);		/* if not loaded, jump to.. */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action))+5);
		  bufferConcat((yyval.action), (yyvsp[0].action));			  /* ..here */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[-2].action)));
		  bufferConcat((yyval.action), (yyvsp[-2].action)); }
#line 1895 "swf4compiler.tab.c"
    break;

  case 23: /* if_stmt: IF '(' FRAMELOADED '(' expr ')' ')' stmt  */
#line 264 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-3].action);
		  bufferWriteU8((yyval.action), SWFACTION_WAITFORFRAME2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 1);		/* if not loaded, jump to.. */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), 5);
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);	  /* ..here */
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action)));	  /* ..and then out */
		  bufferConcat((yyval.action), (yyvsp[0].action)); }
#line 1911 "swf4compiler.tab.c"
    break;

  case 24: /* if_stmt: IF '(' '!' FRAMELOADED '(' expr ')' ')' stmt  */
#line 278 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-3].action);
		  bufferWriteU8((yyval.action), SWFACTION_WAITFORFRAME2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 1);		/* if not loaded, jump to.. */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action)));
		  bufferConcat((yyval.action), (yyvsp[0].action)); }
#line 1924 "swf4compiler.tab.c"
    break;

  case 25: /* if_stmt: IF '(' expr ')' stmt ELSE stmt  */
#line 288 "./swf4compiler.y"
                { bufferWriteU8((yyvsp[-4].action), SWFACTION_IF);
		  bufferWriteS16((yyvsp[-4].action), 2);
		  bufferWriteS16((yyvsp[-4].action), bufferLength((yyvsp[0].action))+5);
		  bufferConcat((yyvsp[-4].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-4].action), SWFACTION_JUMP);
		  bufferWriteS16((yyvsp[-4].action), 2);
		  bufferWriteS16((yyvsp[-4].action), bufferLength((yyvsp[-2].action)));
		  bufferConcat((yyvsp[-4].action), (yyvsp[-2].action));
		  (yyval.action) = (yyvsp[-4].action); }
#line 1938 "swf4compiler.tab.c"
    break;

  case 26: /* if_stmt: IF '(' expr ')' stmt  */
#line 299 "./swf4compiler.y"
                { bufferWriteU8((yyvsp[-2].action), SWFACTION_LOGICALNOT);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_IF);
		  bufferWriteS16((yyvsp[-2].action), 2);
		  bufferWriteS16((yyvsp[-2].action), bufferLength((yyvsp[0].action)));
		  bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  (yyval.action) = (yyvsp[-2].action); }
#line 1949 "swf4compiler.tab.c"
    break;

  case 27: /* expr_opt: %empty  */
#line 308 "./swf4compiler.y"
                        { (yyval.action) = NULL; }
#line 1955 "swf4compiler.tab.c"
    break;

  case 28: /* expr_opt: expr  */
#line 309 "./swf4compiler.y"
                        { (yyval.action) = (yyvsp[0].action); }
#line 1961 "swf4compiler.tab.c"
    break;

  case 29: /* iter_stmt: WHILE '(' '!' FRAMELOADED '(' NUMBER ')' ')' stmt  */
#line 334 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_WAITFORFRAME);
		  bufferWriteS16((yyval.action), 3);
		  bufferWriteS16((yyval.action), atoi((yyvsp[-3].str)));
		  free((yyvsp[-3].str));
		  bufferWriteU8((yyval.action), 1);		/* if not loaded, jump to.. */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action))+5);
		  bufferConcat((yyval.action), (yyvsp[0].action));				  /* ..here */
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), -(bufferLength((yyval.action))+2)); }
#line 1979 "swf4compiler.tab.c"
    break;

  case 30: /* iter_stmt: WHILE '(' expr ')' stmt  */
#line 349 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferWriteU8((yyval.action), SWFACTION_LOGICALNOT);
		  bufferWriteU8((yyval.action), SWFACTION_IF);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), bufferLength((yyvsp[0].action))+5);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), -(bufferLength((yyval.action))+2));
		  bufferResolveJumps((yyval.action)); }
#line 1994 "swf4compiler.tab.c"
    break;

  case 31: /* iter_stmt: DO stmt WHILE '(' expr ')'  */
#line 361 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-4].action);
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_IF);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), -(bufferLength((yyval.action))+2));
		  bufferResolveJumps((yyval.action)); }
#line 2005 "swf4compiler.tab.c"
    break;

  case 32: /* iter_stmt: FOR '(' assign_stmts_opt ';' expr_opt ';' assign_stmts_opt ')' stmt  */
#line 369 "./swf4compiler.y"
                { if (!(yyvsp[-4].action))
                    (yyvsp[-4].action) = newBuffer();
                  else {
                    bufferWriteU8((yyvsp[-4].action), SWFACTION_LOGICALNOT);
                    bufferWriteU8((yyvsp[-4].action), SWFACTION_IF);
                    bufferWriteS16((yyvsp[-4].action), 2);
                    bufferWriteS16((yyvsp[-4].action), bufferLength((yyvsp[0].action))+bufferLength((yyvsp[-2].action))+5);
                  }
                  bufferConcat((yyvsp[-4].action), (yyvsp[0].action));
                  bufferConcat((yyvsp[-4].action), (yyvsp[-2].action));
                  bufferWriteU8((yyvsp[-4].action), SWFACTION_JUMP);
                  bufferWriteS16((yyvsp[-4].action), 2);
                  bufferWriteS16((yyvsp[-4].action), -(bufferLength((yyvsp[-4].action))+2));
                  bufferResolveJumps((yyvsp[-4].action));
                  (yyval.action) = (yyvsp[-6].action);
                  if(!(yyval.action)) (yyval.action) = newBuffer();
                  bufferConcat((yyval.action), (yyvsp[-4].action));
                }
#line 2028 "swf4compiler.tab.c"
    break;

  case 33: /* assign_stmts_opt: %empty  */
#line 390 "./swf4compiler.y"
                                                { (yyval.action) = NULL; }
#line 2034 "swf4compiler.tab.c"
    break;

  case 35: /* cont_stmt: CONTINUE ';'  */
#line 396 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), MAGIC_CONTINUE_NUMBER); }
#line 2043 "swf4compiler.tab.c"
    break;

  case 36: /* break_stmt: BREAK ';'  */
#line 404 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_JUMP);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), MAGIC_BREAK_NUMBER); }
#line 2052 "swf4compiler.tab.c"
    break;

  case 37: /* urlmethod: %empty  */
#line 412 "./swf4compiler.y"
                                { (yyval.getURLMethod) = GETURL_METHOD_NOSEND; }
#line 2058 "swf4compiler.tab.c"
    break;

  case 38: /* urlmethod: ',' STRING  */
#line 414 "./swf4compiler.y"
                                { if(strcmp((yyvsp[0].str), "GET") == 0)
				    (yyval.getURLMethod) = GETURL_METHOD_GET;
				  else if(strcmp((yyvsp[0].str), "POST") == 0)
				    (yyval.getURLMethod) = GETURL_METHOD_POST; }
#line 2067 "swf4compiler.tab.c"
    break;

  case 39: /* level: expr  */
#line 422 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), "_level", 7);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteOp((yyval.action), SWFACTION_STRINGCONCAT); }
#line 2076 "swf4compiler.tab.c"
    break;

  case 40: /* void_function_call: STOPDRAG '(' ')'  */
#line 430 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_ENDDRAG); }
#line 2083 "swf4compiler.tab.c"
    break;

  case 41: /* void_function_call: CALLFRAME '(' variable ')'  */
#line 434 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-1].str), strlen((yyvsp[-1].str))+1);
		  bufferWriteU8((yyval.action), SWFACTION_CALLFRAME);
		  bufferWriteS16((yyval.action), 0);
		  free((yyvsp[-1].str)); }
#line 2093 "swf4compiler.tab.c"
    break;

  case 42: /* void_function_call: CALLFRAME '(' STRING ')'  */
#line 441 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-1].str), strlen((yyvsp[-1].str))+1);
		  bufferWriteU8((yyval.action), SWFACTION_CALLFRAME);
		  bufferWriteS16((yyval.action), 0);
		  free((yyvsp[-1].str)); }
#line 2103 "swf4compiler.tab.c"
    break;

  case 43: /* void_function_call: REMOVECLIP '(' expr ')'  */
#line 448 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_REMOVECLIP); }
#line 2110 "swf4compiler.tab.c"
    break;

  case 44: /* void_function_call: TRACE '(' expr ')'  */
#line 452 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_TRACE); }
#line 2117 "swf4compiler.tab.c"
    break;

  case 45: /* void_function_call: GETURL '(' expr ',' expr ')'  */
#line 457 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-3].action);
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETURL2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), GETURL_METHOD_NOSEND); }
#line 2127 "swf4compiler.tab.c"
    break;

  case 46: /* void_function_call: GETURL '(' expr ',' expr urlmethod ')'  */
#line 464 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-4].action);
		  bufferConcat((yyval.action), (yyvsp[-2].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETURL2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), (yyvsp[-1].getURLMethod)); }
#line 2137 "swf4compiler.tab.c"
    break;

  case 47: /* void_function_call: GETURL1 '(' STRING ',' STRING ')'  */
#line 471 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_GETURL);
		  bufferWriteS16((yyval.action), strlen((yyvsp[-3].str)) + strlen((yyvsp[-1].str)) + 2);
		  bufferWriteHardString((yyval.action), (yyvsp[-3].str), strlen((yyvsp[-3].str)));
		  bufferWriteU8((yyval.action), 0);
		  bufferWriteHardString((yyval.action), (yyvsp[-1].str), strlen((yyvsp[-1].str)));
		  bufferWriteU8((yyval.action), 0); }
#line 2149 "swf4compiler.tab.c"
    break;

  case 48: /* void_function_call: LOADMOVIE '(' expr ',' expr urlmethod ')'  */
#line 480 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-4].action);
		  bufferConcat((yyval.action), (yyvsp[-2].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETURL2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), (yyvsp[-1].getURLMethod) | GETURL_LOADMOVIE); }
#line 2159 "swf4compiler.tab.c"
    break;

  case 49: /* void_function_call: LOADMOVIENUM '(' expr ',' level urlmethod ')'  */
#line 487 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-4].action);
		  bufferConcat((yyval.action), (yyvsp[-2].action));
		  bufferWriteOp((yyval.action), SWFACTION_GETURL2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), (yyvsp[-1].getURLMethod)); }
#line 2169 "swf4compiler.tab.c"
    break;

  case 50: /* void_function_call: LOADVARIABLES '(' expr ',' expr urlmethod ')'  */
#line 494 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-4].action);
		  bufferConcat((yyval.action), (yyvsp[-2].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETURL2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 0xc0 + (yyvsp[-1].getURLMethod)); }
#line 2179 "swf4compiler.tab.c"
    break;

  case 51: /* void_function_call: STARTDRAG '(' expr ',' expr ')'  */
#line 502 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), "0", 2); /* no constraint */
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferConcat((yyval.action), (yyvsp[-3].action));
		  bufferWriteU8((yyval.action), SWFACTION_STARTDRAG); }
#line 2189 "swf4compiler.tab.c"
    break;

  case 52: /* void_function_call: STARTDRAG '(' expr ',' expr ',' expr ',' expr ',' expr ',' expr ')'  */
#line 509 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferConcat((yyval.action), (yyvsp[-7].action));
		  bufferConcat((yyval.action), (yyvsp[-3].action));
		  bufferConcat((yyval.action), (yyvsp[-5].action));
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteString((yyval.action), "1", 2); /* has constraint */
		  bufferConcat((yyval.action), (yyvsp[-9].action));
		  bufferConcat((yyval.action), (yyvsp[-11].action));
		  bufferWriteU8((yyval.action), SWFACTION_STARTDRAG); }
#line 2203 "swf4compiler.tab.c"
    break;

  case 53: /* void_function_call: DUPLICATECLIP '(' expr ',' expr ',' expr ')'  */
#line 521 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-5].action);
		  bufferConcat((yyval.action), (yyvsp[-3].action));
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteWTHITProperty((yyval.action));
		  bufferWriteU8((yyval.action), SWFACTION_ADD); /* see docs for explanation */
		  bufferWriteU8((yyval.action), SWFACTION_DUPLICATECLIP); }
#line 2214 "swf4compiler.tab.c"
    break;

  case 54: /* void_function_call: NEXTFRAME '(' ')'  */
#line 530 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_NEXTFRAME); }
#line 2221 "swf4compiler.tab.c"
    break;

  case 55: /* void_function_call: PREVFRAME '(' ')'  */
#line 534 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_PREVFRAME); }
#line 2228 "swf4compiler.tab.c"
    break;

  case 56: /* void_function_call: PLAY '(' ')'  */
#line 538 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_PLAY); }
#line 2235 "swf4compiler.tab.c"
    break;

  case 57: /* void_function_call: STOP '(' ')'  */
#line 542 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_STOP); }
#line 2242 "swf4compiler.tab.c"
    break;

  case 58: /* void_function_call: TOGGLEQUALITY '(' ')'  */
#line 546 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_TOGGLEQUALITY); }
#line 2249 "swf4compiler.tab.c"
    break;

  case 59: /* void_function_call: STOPSOUNDS '(' ')'  */
#line 550 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_STOPSOUNDS); }
#line 2256 "swf4compiler.tab.c"
    break;

  case 60: /* void_function_call: GOTOFRAME '(' NUMBER ')'  */
#line 554 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_GOTOFRAME);
		  bufferWriteS16((yyval.action), 2);
		  bufferWriteS16((yyval.action), atoi((yyvsp[-1].str)));
		  free((yyvsp[-1].str)); }
#line 2266 "swf4compiler.tab.c"
    break;

  case 61: /* void_function_call: GOTOFRAME '(' STRING ')'  */
#line 561 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_GOTOLABEL);
		  bufferWriteS16((yyval.action), strlen((yyvsp[-1].str))+1);
		  bufferWriteHardString((yyval.action), (yyvsp[-1].str), strlen((yyvsp[-1].str))+1);
		  free((yyvsp[-1].str)); }
#line 2276 "swf4compiler.tab.c"
    break;

  case 62: /* void_function_call: GOTOFRAME '(' expr ')'  */
#line 568 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_GOTOFRAME2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 0); }
#line 2285 "swf4compiler.tab.c"
    break;

  case 63: /* void_function_call: GOTOANDPLAY '(' expr ')'  */
#line 574 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_GOTOFRAME2);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 1); }
#line 2294 "swf4compiler.tab.c"
    break;

  case 64: /* void_function_call: SETTARGET '(' STRING ')'  */
#line 580 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_SETTARGET);
		  bufferWriteS16((yyval.action), strlen((yyvsp[-1].str))+1);
		  bufferWriteHardString((yyval.action), (yyvsp[-1].str), strlen((yyvsp[-1].str))+1);
		  free((yyvsp[-1].str)); }
#line 2304 "swf4compiler.tab.c"
    break;

  case 65: /* void_function_call: SETTARGET '(' expr ')'  */
#line 587 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_SETTARGET2); }
#line 2311 "swf4compiler.tab.c"
    break;

  case 66: /* void_function_call: TELLTARGET '(' STRING ')' stmt  */
#line 591 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
			/* SetTarget(STRING) */
		  bufferWriteU8((yyval.action), SWFACTION_SETTARGET);
		  bufferWriteS16((yyval.action), strlen((yyvsp[-2].str))+1);
		  bufferWriteHardString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
			/* stmt */
		  bufferConcat((yyval.action), (yyvsp[0].action));
			/* SetTarget('') */
		  bufferWriteU8((yyval.action), SWFACTION_SETTARGET);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 0);
		  free((yyvsp[-2].str)); }
#line 2328 "swf4compiler.tab.c"
    break;

  case 67: /* void_function_call: TELLTARGET '(' expr ')' stmt  */
#line 605 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
			/* SetTarget(expr) */
		  bufferWriteU8((yyval.action), SWFACTION_SETTARGET2); 
			/* stmt */
		  bufferConcat((yyval.action), (yyvsp[0].action));
			/* SetTarget('') */
		  bufferWriteU8((yyval.action), SWFACTION_SETTARGET);
		  bufferWriteS16((yyval.action), 1);
		  bufferWriteU8((yyval.action), 0); }
#line 2342 "swf4compiler.tab.c"
    break;

  case 68: /* function_call: EVAL '(' expr ')'  */
#line 618 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE); }
#line 2349 "swf4compiler.tab.c"
    break;

  case 69: /* function_call: TIME '(' ')'  */
#line 622 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteU8((yyval.action), SWFACTION_GETTIME); }
#line 2356 "swf4compiler.tab.c"
    break;

  case 70: /* function_call: RANDOM '(' expr ')'  */
#line 626 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_RANDOMNUMBER); }
#line 2363 "swf4compiler.tab.c"
    break;

  case 71: /* function_call: LENGTH '(' expr ')'  */
#line 630 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_STRINGLENGTH); }
#line 2370 "swf4compiler.tab.c"
    break;

  case 72: /* function_call: INT '(' expr ')'  */
#line 634 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_INT); }
#line 2377 "swf4compiler.tab.c"
    break;

  case 73: /* function_call: ORD '(' expr ')'  */
#line 638 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_ORD); }
#line 2384 "swf4compiler.tab.c"
    break;

  case 74: /* function_call: CHR '(' expr ')'  */
#line 642 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action);
		  bufferWriteU8((yyval.action), SWFACTION_CHR); }
#line 2391 "swf4compiler.tab.c"
    break;

  case 75: /* function_call: CONCAT '(' expr ',' expr ')'  */
#line 646 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-3].action);
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_STRINGCONCAT); }
#line 2399 "swf4compiler.tab.c"
    break;

  case 76: /* function_call: SUBSTR '(' expr ',' expr ',' expr ')'  */
#line 651 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-5].action);
		  bufferConcat((yyval.action), (yyvsp[-3].action));
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_SUBSTRING); }
#line 2408 "swf4compiler.tab.c"
    break;

  case 77: /* function_call: GETPROPERTY '(' expr ',' STRING ')'  */
#line 657 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferConcat((yyval.action), (yyvsp[-3].action));
		  bufferWriteProperty((yyval.action), (yyvsp[-1].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  free((yyvsp[-1].str)); }
#line 2418 "swf4compiler.tab.c"
    break;

  case 78: /* pf_expr: lhs_expr "++"  */
#line 666 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteBuffer((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteBuffer((yyval.action), (yyvsp[-1].action));
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_ADD);
		  bufferWriteU8((yyval.action), SWFACTION_SETVARIABLE); }
#line 2432 "swf4compiler.tab.c"
    break;

  case 79: /* pf_expr: lhs_expr "--"  */
#line 677 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteBuffer((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteBuffer((yyval.action), (yyvsp[-1].action));
		  bufferConcat((yyval.action), (yyvsp[-1].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_SUBTRACT);
		  bufferWriteU8((yyval.action), SWFACTION_SETVARIABLE); }
#line 2446 "swf4compiler.tab.c"
    break;

  case 81: /* rhs_expr: '(' rhs_expr ')'  */
#line 693 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-1].action); }
#line 2452 "swf4compiler.tab.c"
    break;

  case 82: /* rhs_expr: NUMBER  */
#line 696 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[0].str), strlen((yyvsp[0].str))+1);
		  free((yyvsp[0].str)); }
#line 2460 "swf4compiler.tab.c"
    break;

  case 83: /* rhs_expr: '-' NUMBER  */
#line 701 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), "-", 2);
		  bufferWriteString((yyval.action), (yyvsp[0].str), strlen((yyvsp[0].str))+1);
		  free((yyvsp[0].str)); }
#line 2469 "swf4compiler.tab.c"
    break;

  case 84: /* rhs_expr: STRING  */
#line 707 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[0].str), strlen((yyvsp[0].str))+1);
		  free((yyvsp[0].str)); }
#line 2477 "swf4compiler.tab.c"
    break;

  case 85: /* rhs_expr: variable  */
#line 712 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[0].str), strlen((yyvsp[0].str))+1);
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  free((yyvsp[0].str)); }
#line 2486 "swf4compiler.tab.c"
    break;

  case 86: /* rhs_expr: sprite  */
#line 718 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[0].str), strlen((yyvsp[0].str))+1);
		  free((yyvsp[0].str)); }
#line 2494 "swf4compiler.tab.c"
    break;

  case 87: /* rhs_expr: sprite '.' IDENTIFIER  */
#line 723 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  free((yyvsp[0].str));
		  free((yyvsp[-2].str)); }
#line 2505 "swf4compiler.tab.c"
    break;

  case 88: /* rhs_expr: "++" sprite '.' IDENTIFIER  */
#line 731 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_ADD);
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  free((yyvsp[-2].str));
		  free((yyvsp[0].str)); }
#line 2523 "swf4compiler.tab.c"
    break;

  case 89: /* rhs_expr: "++" lhs_expr  */
#line 746 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferWriteU8((yyval.action), SWFACTION_PUSHDUP);
		  bufferWriteU8((yyval.action), SWFACTION_PUSHDUP);
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_ADD);
		  bufferWriteU8((yyval.action), SWFACTION_SETVARIABLE);
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE); }
#line 2536 "swf4compiler.tab.c"
    break;

  case 90: /* rhs_expr: "--" sprite '.' IDENTIFIER  */
#line 756 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_ADD);
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  free((yyvsp[-2].str));
		  free((yyvsp[0].str)); }
#line 2554 "swf4compiler.tab.c"
    break;

  case 91: /* rhs_expr: "--" lhs_expr  */
#line 771 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferWriteU8((yyval.action), SWFACTION_PUSHDUP);
		  bufferWriteU8((yyval.action), SWFACTION_PUSHDUP);
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_SUBTRACT);
		  bufferWriteU8((yyval.action), SWFACTION_SETVARIABLE);
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE); }
#line 2567 "swf4compiler.tab.c"
    break;

  case 92: /* rhs_expr: '-' rhs_expr  */
#line 781 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferWriteString((yyvsp[0].action), "-1", 3);
		  bufferWriteU8((yyvsp[0].action), SWFACTION_MULTIPLY); }
#line 2575 "swf4compiler.tab.c"
    break;

  case 93: /* rhs_expr: '!' rhs_expr  */
#line 786 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferWriteU8((yyvsp[0].action), SWFACTION_LOGICALNOT); }
#line 2582 "swf4compiler.tab.c"
    break;

  case 94: /* rhs_expr: lhs_expr '=' rhs_expr  */
#line 790 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_PUSHDUP);
		  bufferWriteU8((yyval.action), SWFACTION_SETVARIABLE); }
#line 2591 "swf4compiler.tab.c"
    break;

  case 95: /* rhs_expr: rhs_expr '*' rhs_expr  */
#line 796 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_MULTIPLY); }
#line 2599 "swf4compiler.tab.c"
    break;

  case 96: /* rhs_expr: rhs_expr '/' rhs_expr  */
#line 801 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_DIVIDE); }
#line 2607 "swf4compiler.tab.c"
    break;

  case 97: /* rhs_expr: rhs_expr '+' rhs_expr  */
#line 806 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_ADD); }
#line 2615 "swf4compiler.tab.c"
    break;

  case 98: /* rhs_expr: rhs_expr '-' rhs_expr  */
#line 811 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_SUBTRACT); }
#line 2623 "swf4compiler.tab.c"
    break;

  case 99: /* rhs_expr: rhs_expr '&' rhs_expr  */
#line 816 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_STRINGCONCAT); }
#line 2631 "swf4compiler.tab.c"
    break;

  case 100: /* rhs_expr: rhs_expr '<' rhs_expr  */
#line 821 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[-2].action);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_LESSTHAN); }
#line 2639 "swf4compiler.tab.c"
    break;

  case 101: /* rhs_expr: rhs_expr '>' rhs_expr  */
#line 826 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferConcat((yyval.action), (yyvsp[-2].action));
		  bufferWriteU8((yyval.action), SWFACTION_LESSTHAN); }
#line 2647 "swf4compiler.tab.c"
    break;

  case 102: /* rhs_expr: rhs_expr "<=" rhs_expr  */
#line 831 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferConcat((yyval.action), (yyvsp[-2].action));
		  bufferWriteU8((yyval.action), SWFACTION_LESSTHAN);
		  bufferWriteU8((yyval.action), SWFACTION_LOGICALNOT); }
#line 2656 "swf4compiler.tab.c"
    break;

  case 103: /* rhs_expr: rhs_expr ">=" rhs_expr  */
#line 837 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_LESSTHAN);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_LOGICALNOT); }
#line 2664 "swf4compiler.tab.c"
    break;

  case 104: /* rhs_expr: rhs_expr "!==" rhs_expr  */
#line 842 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_STRINGEQ);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_LOGICALNOT); }
#line 2672 "swf4compiler.tab.c"
    break;

  case 105: /* rhs_expr: rhs_expr "===" rhs_expr  */
#line 847 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_STRINGEQ); }
#line 2679 "swf4compiler.tab.c"
    break;

  case 106: /* rhs_expr: rhs_expr "<=>" rhs_expr  */
#line 851 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_STRINGCOMPARE); }
#line 2686 "swf4compiler.tab.c"
    break;

  case 107: /* rhs_expr: rhs_expr "==" rhs_expr  */
#line 855 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_EQUAL); }
#line 2693 "swf4compiler.tab.c"
    break;

  case 108: /* rhs_expr: rhs_expr "!=" rhs_expr  */
#line 859 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_EQUAL);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_LOGICALNOT); }
#line 2701 "swf4compiler.tab.c"
    break;

  case 109: /* rhs_expr: rhs_expr "&&" rhs_expr  */
#line 864 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_LOGICALAND); }
#line 2708 "swf4compiler.tab.c"
    break;

  case 110: /* rhs_expr: rhs_expr "||" rhs_expr  */
#line 868 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_LOGICALOR); }
#line 2715 "swf4compiler.tab.c"
    break;

  case 111: /* rhs_expr: rhs_expr '?' rhs_expr ':' rhs_expr  */
#line 872 "./swf4compiler.y"
                { bufferWriteU8((yyvsp[-4].action), SWFACTION_IF);
		  bufferWriteS16((yyvsp[-4].action), 2);
		  bufferWriteS16((yyvsp[-4].action), bufferLength((yyvsp[0].action))+5);
		  bufferConcat((yyvsp[-4].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-4].action), SWFACTION_JUMP);
		  bufferWriteS16((yyvsp[-4].action), 2);
		  bufferWriteS16((yyvsp[-4].action), bufferLength((yyvsp[-2].action)));
		  bufferConcat((yyvsp[-4].action), (yyvsp[-2].action)); }
#line 2728 "swf4compiler.tab.c"
    break;

  case 113: /* variable: sprite ':' IDENTIFIER  */
#line 886 "./swf4compiler.y"
                { (yyval.str) = (yyvsp[-2].str);
		  (yyval.str) = stringConcat((yyval.str), strdup(":"));
		  (yyval.str) = stringConcat((yyval.str), (yyvsp[0].str)); }
#line 2736 "swf4compiler.tab.c"
    break;

  case 114: /* sprite: THIS  */
#line 893 "./swf4compiler.y"
                { (yyval.str) = strdup(""); }
#line 2742 "swf4compiler.tab.c"
    break;

  case 115: /* sprite: '.'  */
#line 896 "./swf4compiler.y"
                { (yyval.str) = strdup(""); }
#line 2748 "swf4compiler.tab.c"
    break;

  case 116: /* sprite: '/'  */
#line 899 "./swf4compiler.y"
                { (yyval.str) = strdup("/"); }
#line 2754 "swf4compiler.tab.c"
    break;

  case 117: /* sprite: ".."  */
#line 902 "./swf4compiler.y"
                { (yyval.str) = strdup(".."); }
#line 2760 "swf4compiler.tab.c"
    break;

  case 118: /* sprite: IDENTIFIER  */
#line 905 "./swf4compiler.y"
                { (yyval.str) = (yyvsp[0].str); }
#line 2766 "swf4compiler.tab.c"
    break;

  case 119: /* sprite: PATH  */
#line 908 "./swf4compiler.y"
                { (yyval.str) = (yyvsp[0].str); }
#line 2772 "swf4compiler.tab.c"
    break;

  case 120: /* lhs_expr: variable  */
#line 913 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[0].str), strlen((yyvsp[0].str))+1);
		  free((yyvsp[0].str)); }
#line 2780 "swf4compiler.tab.c"
    break;

  case 121: /* lhs_expr: STRING  */
#line 918 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[0].str), strlen((yyvsp[0].str))+1);
		  free((yyvsp[0].str)); }
#line 2788 "swf4compiler.tab.c"
    break;

  case 122: /* lhs_expr: '(' rhs_expr ')'  */
#line 922 "./swf4compiler.y"
                                { (yyval.action) = (yyvsp[-1].action); }
#line 2794 "swf4compiler.tab.c"
    break;

  case 124: /* $@1: %empty  */
#line 929 "./swf4compiler.y"
                { asmBuffer = newBuffer(); }
#line 2800 "swf4compiler.tab.c"
    break;

  case 125: /* assign_stmt: ASM '{' $@1 opcode_list '}'  */
#line 931 "./swf4compiler.y"
                { (yyval.action) = asmBuffer; }
#line 2806 "swf4compiler.tab.c"
    break;

  case 127: /* assign_stmt: "++" lhs_expr  */
#line 936 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferWriteBuffer((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_ADD);
		  bufferWriteU8((yyval.action), SWFACTION_SETVARIABLE); }
#line 2817 "swf4compiler.tab.c"
    break;

  case 128: /* assign_stmt: "--" lhs_expr  */
#line 944 "./swf4compiler.y"
                { (yyval.action) = (yyvsp[0].action);
		  bufferWriteBuffer((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_GETVARIABLE);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_SUBTRACT);
		  bufferWriteU8((yyval.action), SWFACTION_SETVARIABLE); }
#line 2828 "swf4compiler.tab.c"
    break;

  case 129: /* assign_stmt: "++" sprite '.' IDENTIFIER  */
#line 952 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_ADD);
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  free((yyvsp[-2].str));
		  free((yyvsp[0].str)); }
#line 2844 "swf4compiler.tab.c"
    break;

  case 130: /* assign_stmt: "--" sprite '.' IDENTIFIER  */
#line 965 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  bufferWriteString((yyval.action), "1", 2);
		  bufferWriteU8((yyval.action), SWFACTION_SUBTRACT);
		  bufferWriteString((yyval.action), (yyvsp[-2].str), strlen((yyvsp[-2].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[0].str));
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  free((yyvsp[-2].str));
		  free((yyvsp[0].str)); }
#line 2860 "swf4compiler.tab.c"
    break;

  case 131: /* assign_stmt: lhs_expr '=' rhs_expr  */
#line 978 "./swf4compiler.y"
                { bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_SETVARIABLE); }
#line 2867 "swf4compiler.tab.c"
    break;

  case 132: /* assign_stmt: lhs_expr "*=" rhs_expr  */
#line 982 "./swf4compiler.y"
                { bufferWriteBuffer((yyvsp[-2].action), (yyvsp[-2].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_GETVARIABLE);
		  bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_MULTIPLY);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_SETVARIABLE); }
#line 2877 "swf4compiler.tab.c"
    break;

  case 133: /* assign_stmt: lhs_expr "/=" rhs_expr  */
#line 989 "./swf4compiler.y"
                { bufferWriteBuffer((yyvsp[-2].action), (yyvsp[-2].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_GETVARIABLE);
		  bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_DIVIDE);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_SETVARIABLE); }
#line 2887 "swf4compiler.tab.c"
    break;

  case 134: /* assign_stmt: lhs_expr "+=" rhs_expr  */
#line 996 "./swf4compiler.y"
                { bufferWriteBuffer((yyvsp[-2].action), (yyvsp[-2].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_GETVARIABLE);
		  bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_ADD);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_SETVARIABLE); }
#line 2897 "swf4compiler.tab.c"
    break;

  case 135: /* assign_stmt: lhs_expr "-=" rhs_expr  */
#line 1003 "./swf4compiler.y"
                { bufferWriteBuffer((yyvsp[-2].action), (yyvsp[-2].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_GETVARIABLE);
		  bufferConcat((yyvsp[-2].action), (yyvsp[0].action));
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_SUBTRACT);
		  bufferWriteU8((yyvsp[-2].action), SWFACTION_SETVARIABLE); }
#line 2907 "swf4compiler.tab.c"
    break;

  case 136: /* assign_stmt: sprite '.' IDENTIFIER '=' rhs_expr  */
#line 1010 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferConcat((yyval.action),(yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  free((yyvsp[-4].str));
		  free((yyvsp[-2].str)); }
#line 2919 "swf4compiler.tab.c"
    break;

  case 137: /* assign_stmt: sprite '.' IDENTIFIER "*=" rhs_expr  */
#line 1019 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_MULTIPLY);
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  free((yyvsp[-4].str));
		  free((yyvsp[-2].str)); }
#line 2935 "swf4compiler.tab.c"
    break;

  case 138: /* assign_stmt: sprite '.' IDENTIFIER "/=" rhs_expr  */
#line 1032 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_DIVIDE);
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  free((yyvsp[-4].str));
		  free((yyvsp[-2].str)); }
#line 2951 "swf4compiler.tab.c"
    break;

  case 139: /* assign_stmt: sprite '.' IDENTIFIER "+=" rhs_expr  */
#line 1045 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_ADD);
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  free((yyvsp[-4].str));
		  free((yyvsp[-2].str)); }
#line 2967 "swf4compiler.tab.c"
    break;

  case 140: /* assign_stmt: sprite '.' IDENTIFIER "-=" rhs_expr  */
#line 1058 "./swf4compiler.y"
                { (yyval.action) = newBuffer();
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteString((yyval.action), (yyvsp[-4].str), strlen((yyvsp[-4].str))+1);
		  bufferWriteProperty((yyval.action), (yyvsp[-2].str));
		  bufferWriteU8((yyval.action), SWFACTION_GETPROPERTY);
		  bufferConcat((yyval.action), (yyvsp[0].action));
		  bufferWriteU8((yyval.action), SWFACTION_SUBTRACT);
		  bufferWriteU8((yyval.action), SWFACTION_SETPROPERTY);
		  free((yyvsp[-4].str));
		  free((yyvsp[-2].str)); }
#line 2983 "swf4compiler.tab.c"
    break;

  case 142: /* push_item: STRING  */
#line 1076 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteU8(asmBuffer, PUSH_STRING);
				  (yyval.len) += bufferWriteHardString(asmBuffer, (yyvsp[0].str), strlen((yyvsp[0].str)) + 1); }
#line 2990 "swf4compiler.tab.c"
    break;

  case 143: /* push_list: push_item  */
#line 1080 "./swf4compiler.y"
                                        { (yyval.len) = (yyvsp[0].len); }
#line 2996 "swf4compiler.tab.c"
    break;

  case 144: /* push_list: push_list ',' push_item  */
#line 1081 "./swf4compiler.y"
                                        { (yyval.len) = (yyvsp[-2].len) + (yyvsp[0].len); }
#line 3002 "swf4compiler.tab.c"
    break;

  case 146: /* opcode_list: opcode_list opcode  */
#line 1086 "./swf4compiler.y"
                                { (yyval.len) = (yyvsp[-1].len) + (yyvsp[0].len); }
#line 3008 "swf4compiler.tab.c"
    break;

  case 147: /* @2: %empty  */
#line 1090 "./swf4compiler.y"
                                { (yyval.len) = bufferWritePushOp(asmBuffer);
				  (yyval.len) += bufferWriteS16(asmBuffer, 0); }
#line 3015 "swf4compiler.tab.c"
    break;

  case 148: /* opcode: ASMPUSH @2 push_list  */
#line 1092 "./swf4compiler.y"
                                { (yyval.len) = (yyvsp[-1].len) + (yyvsp[0].len);
			
				  bufferPatchLength(asmBuffer, (yyvsp[0].len)); }
#line 3023 "swf4compiler.tab.c"
    break;

  case 149: /* opcode: ASMADD  */
#line 1096 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_ADD); }
#line 3029 "swf4compiler.tab.c"
    break;

  case 150: /* opcode: ASMSUBSTRACT  */
#line 1097 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_SUBTRACT); }
#line 3035 "swf4compiler.tab.c"
    break;

  case 151: /* opcode: ASMMULTIPLY  */
#line 1098 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_MULTIPLY); }
#line 3041 "swf4compiler.tab.c"
    break;

  case 152: /* opcode: ASMDIVIDE  */
#line 1099 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_DIVIDE); }
#line 3047 "swf4compiler.tab.c"
    break;

  case 153: /* opcode: ASMEQUALS  */
#line 1100 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_EQUAL); }
#line 3053 "swf4compiler.tab.c"
    break;

  case 154: /* opcode: ASMLESS  */
#line 1101 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_LESSTHAN); }
#line 3059 "swf4compiler.tab.c"
    break;

  case 155: /* opcode: ASMLOGICALAND  */
#line 1102 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_LOGICALAND); }
#line 3065 "swf4compiler.tab.c"
    break;

  case 156: /* opcode: ASMLOGICALOR  */
#line 1103 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_LOGICALOR); }
#line 3071 "swf4compiler.tab.c"
    break;

  case 157: /* opcode: ASMLOGICALNOT  */
#line 1104 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_LOGICALNOT); }
#line 3077 "swf4compiler.tab.c"
    break;

  case 158: /* opcode: ASMSTRINGAND  */
#line 1105 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_STRINGCONCAT); }
#line 3083 "swf4compiler.tab.c"
    break;

  case 159: /* opcode: ASMSTRINGEQUALS  */
#line 1106 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_STRINGEQ); }
#line 3089 "swf4compiler.tab.c"
    break;

  case 160: /* opcode: ASMSTRINGLENGTH  */
#line 1107 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_STRINGLENGTH); }
#line 3095 "swf4compiler.tab.c"
    break;

  case 161: /* opcode: ASMSTRINGEXTRACT  */
#line 1108 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_SUBSTRING); }
#line 3101 "swf4compiler.tab.c"
    break;

  case 162: /* opcode: ASMMBSTRINGEXTRACT  */
#line 1109 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_MBSUBSTRING); }
#line 3107 "swf4compiler.tab.c"
    break;

  case 163: /* opcode: ASMMBSTRINGLENGTH  */
#line 1110 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_MBLENGTH); }
#line 3113 "swf4compiler.tab.c"
    break;

  case 164: /* opcode: ASMSTRINGLESS  */
#line 1111 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_STRINGCOMPARE); }
#line 3119 "swf4compiler.tab.c"
    break;

  case 165: /* opcode: ASMPOP  */
#line 1112 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_POP); }
#line 3125 "swf4compiler.tab.c"
    break;

  case 166: /* opcode: ASMASCIITOCHAR  */
#line 1113 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_CHR); }
#line 3131 "swf4compiler.tab.c"
    break;

  case 167: /* opcode: ASMCHARTOASCII  */
#line 1114 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_ORD); }
#line 3137 "swf4compiler.tab.c"
    break;

  case 168: /* opcode: ASMTOINTEGER  */
#line 1115 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_INT); }
#line 3143 "swf4compiler.tab.c"
    break;

  case 169: /* opcode: ASMMBASCIITOCHAR  */
#line 1116 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_MBCHR); }
#line 3149 "swf4compiler.tab.c"
    break;

  case 170: /* opcode: ASMMBCHARTOASCII  */
#line 1117 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_MBORD); }
#line 3155 "swf4compiler.tab.c"
    break;

  case 171: /* opcode: ASMCALL  */
#line 1118 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_CALLFRAME); }
#line 3161 "swf4compiler.tab.c"
    break;

  case 172: /* opcode: ASMGETVARIABLE  */
#line 1119 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_GETVARIABLE); }
#line 3167 "swf4compiler.tab.c"
    break;

  case 173: /* opcode: ASMSETVARIABLE  */
#line 1120 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_SETVARIABLE); }
#line 3173 "swf4compiler.tab.c"
    break;

  case 174: /* opcode: ASMGETPROPERTY  */
#line 1121 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_GETPROPERTY); }
#line 3179 "swf4compiler.tab.c"
    break;

  case 175: /* opcode: ASMSETPROPERTY  */
#line 1122 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_SETPROPERTY); }
#line 3185 "swf4compiler.tab.c"
    break;

  case 176: /* opcode: ASMREMOVESPRITE  */
#line 1123 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_REMOVECLIP); }
#line 3191 "swf4compiler.tab.c"
    break;

  case 177: /* opcode: ASMSETTARGET2  */
#line 1124 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_SETTARGET2); }
#line 3197 "swf4compiler.tab.c"
    break;

  case 178: /* opcode: ASMSTARTDRAG  */
#line 1125 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_STARTDRAG); }
#line 3203 "swf4compiler.tab.c"
    break;

  case 179: /* opcode: ASMENDDRAG  */
#line 1126 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_ENDDRAG); }
#line 3209 "swf4compiler.tab.c"
    break;

  case 180: /* opcode: ASMCLONESPRITE  */
#line 1127 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_DUPLICATECLIP); }
#line 3215 "swf4compiler.tab.c"
    break;

  case 181: /* opcode: ASMGETTIME  */
#line 1128 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_GETTIME); }
#line 3221 "swf4compiler.tab.c"
    break;

  case 182: /* opcode: ASMRANDOMNUMBER  */
#line 1129 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_RANDOMNUMBER); }
#line 3227 "swf4compiler.tab.c"
    break;

  case 183: /* opcode: ASMTRACE  */
#line 1130 "./swf4compiler.y"
                                { (yyval.len) = bufferWriteOp(asmBuffer, SWFACTION_TRACE); }
#line 3233 "swf4compiler.tab.c"
    break;

  case 184: /* opcode: ASMIF NUMBER  */
#line 1132 "./swf4compiler.y"
                                { (yyval.len) = ( 
					bufferWriteOp(asmBuffer, SWFACTION_IF)
					+ bufferWriteS16(asmBuffer, 2)
					+ bufferWriteS16(asmBuffer, atoi((yyvsp[0].str)))); }
#line 3242 "swf4compiler.tab.c"
    break;

  case 185: /* opcode: ASMJUMP NUMBER  */
#line 1136 "./swf4compiler.y"
                                { (yyval.len) =  ( 
					bufferWriteOp(asmBuffer, SWFACTION_JUMP)
					+ bufferWriteS16(asmBuffer, 2)
					+ bufferWriteS16(asmBuffer, atoi((yyvsp[0].str)))); }
#line 3251 "swf4compiler.tab.c"
    break;

  case 186: /* opcode: ASMGETURL2 NUMBER  */
#line 1140 "./swf4compiler.y"
                                { (yyval.len) =  (bufferWriteOp(asmBuffer, SWFACTION_GETURL2)
					+ bufferWriteS16(asmBuffer, 1) 
					+ bufferWriteU8(asmBuffer, atoi((yyvsp[0].str)))); }
#line 3259 "swf4compiler.tab.c"
    break;

  case 187: /* opcode: ASMGOTOFRAME2 NUMBER  */
#line 1143 "./swf4compiler.y"
                                { (yyval.len) =  (bufferWriteOp(asmBuffer, SWFACTION_GOTOFRAME2) 
					+ bufferWriteS16(asmBuffer, 1)
					+ bufferWriteU8(asmBuffer, atoi((yyvsp[0].str)))); 
					/* SceneBias missing */ }
#line 3268 "swf4compiler.tab.c"
    break;

  case 188: /* opcode: ASMWAITFORFRAME2 NUMBER  */
#line 1147 "./swf4compiler.y"
                                  { (yyval.len) = (bufferWriteOp(asmBuffer, SWFACTION_WAITFORFRAME2) 
					+ bufferWriteS16(asmBuffer, 1)
					+ bufferWriteU8(asmBuffer, atoi((yyvsp[0].str)))); }
#line 3276 "swf4compiler.tab.c"
    break;


#line 3280 "swf4compiler.tab.c"

      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", YY_CAST (yysymbol_kind_t, yyr1[yyn]), &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */
  {
    const int yylhs = yyr1[yyn] - YYNTOKENS;
    const int yyi = yypgoto[yylhs] + *yyssp;
    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
               ? yytable[yyi]
               : yydefgoto[yylhs]);
  }

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
      yyerror (buffer, YY_("syntax error"));
    }

  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval, buffer);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:
  /* Pacify compilers when the user code never invokes YYERROR and the
     label yyerrorlab therefore never appears in user code.  */
  if (0)
    YYERROR;
  ++yynerrs;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  /* Pop stack until we find a state that shifts the error token.  */
  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYSYMBOL_YYerror;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYSYMBOL_YYerror)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  YY_ACCESSING_SYMBOL (yystate), yyvsp, buffer);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", YY_ACCESSING_SYMBOL (yyn), yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturnlab;


/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturnlab;


/*-----------------------------------------------------------.
| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
`-----------------------------------------------------------*/
yyexhaustedlab:
  yyerror (buffer, YY_("memory exhausted"));
  yyresult = 2;
  goto yyreturnlab;


/*----------------------------------------------------------.
| yyreturnlab -- parsing is finished, clean up and return.  |
`----------------------------------------------------------*/
yyreturnlab:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval, buffer);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  YY_ACCESSING_SYMBOL (+*yyssp), yyvsp, buffer);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif

  return yyresult;
}

#line 1153 "./swf4compiler.y"

